@@ -18,36 +18,39 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "aliens.h"
+#include "Starfighter.h"
 
-signed char placeAlien(object *theEnemy)
+object defEnemy[MAX_DEFALIENS];
+object enemy[MAX_ALIENS];
+
+static bool placeAlien(object *theEnemy)
 {
 	if (rand() % 2 == 0)
-		theEnemy->x = Math::rrand(800, 1600);
+		theEnemy->x = rrand(800, 1600);
 	else
-		theEnemy->x = Math::rrand(-800, 0);
+		theEnemy->x = rrand(-800, 0);
 
 	if (rand() % 2 == 0)
-		theEnemy->y = Math::rrand(600, 1200);
+		theEnemy->y = rrand(600, 1200);
 	else
-		theEnemy->y = Math::rrand(-600, 0);
+		theEnemy->y = rrand(-600, 0);
 
 	if (currentGame.area == 24)
 	{
 		theEnemy->x = 800;
-		theEnemy->y = Math::rrand(200, 400);
+		theEnemy->y = rrand(200, 400);
 	}
 
 	for (int i = 0 ; i < MAX_ALIENS ; i++)
 	{
 		if ((enemy[i].owner != theEnemy) && (enemy[i].shield > 0))
 		{
-			if (Collision::collision(theEnemy->x, theEnemy->y, theEnemy->image[0]->w, theEnemy->image[0]->h, enemy[i].x, enemy[i].y, enemy[i].image[0]->w, enemy[i].image[0]->h))
-				return 0;
+			if (collision(theEnemy->x, theEnemy->y, theEnemy->image[0]->w, theEnemy->image[0]->h, enemy[i].x, enemy[i].y, enemy[i].image[0]->w, enemy[i].image[0]->h))
+				return false;
 		}
 	}
 
-	return 1;
+	return true;
 }
 
 /*
@@ -55,7 +58,7 @@ This simply pulls back an alien from the array that is
 "dead" (no shield) and returns the index number so we can have
 a new one.
 */
-int getAlien()
+static int getAlien()
 {
 	for (int i = 0 ; i < engine.maxAliens ; i++)
 	{
@@ -68,7 +71,7 @@ int getAlien()
 	return -1;
 }
 
-void addDrone(object *host)
+static void addDrone(object *host)
 {
 	int index = getAlien();
 
@@ -76,7 +79,7 @@ void addDrone(object *host)
 		return;
 
 	enemy[index] = defEnemy[CD_DRONE];
-	enemy[index].active = 1;
+	enemy[index].active = true;
 	enemy[index].face = rand() % 2;
 	enemy[index].owner = &enemy[index]; // Most enemies will own themselves
 	enemy[index].target = &enemy[index];
@@ -89,7 +92,7 @@ void addDrone(object *host)
 	enemy[index].y = host->y + rand() % 50;
 }
 
-void addSmallAsteroid(object *host)
+static void addSmallAsteroid(object *host)
 {
 	if (engine.missionCompleteTimer != 0)
 		return;
@@ -101,7 +104,7 @@ void addSmallAsteroid(object *host)
 		addBullet(&weapon[W_ROCKETS], host, 0, 0);
 
 	for (int i = 10 ; i < 20 ; i++)
-		if (enemy[i].active == 0)
+		if (!enemy[i].active)
 			index = i;
 
 	if (index == -1)
@@ -111,8 +114,8 @@ void addSmallAsteroid(object *host)
 	{
 		enemy[index] = defEnemy[CD_ASTEROID2];
 		enemy[index].imageIndex[0] = enemy[index].imageIndex[1] = 39 + rand() % 2;
-		enemy[index].image[0] = graphics.shipShape[enemy[index].imageIndex[0]];
-		enemy[index].image[1] = graphics.shipShape[enemy[index].imageIndex[1]];
+		enemy[index].image[0] = shipShape[enemy[index].imageIndex[0]];
+		enemy[index].image[1] = shipShape[enemy[index].imageIndex[1]];
 	}
 	else
 	{
@@ -128,10 +131,10 @@ void addSmallAsteroid(object *host)
 
 	enemy[index].x = host->x;
 	enemy[index].y = host->y;
-	enemy[index].active = 1;
+	enemy[index].active = true;
 }
 
-signed char addAlien()
+bool addAlien()
 {
 	int index = getAlien();
 
@@ -236,10 +239,10 @@ signed char addAlien()
 			randEnemy = CD_TRANSPORTSHIP;
 	}
 
-	delete(alienArray);
+	delete[] alienArray;
 
 	enemy[index] = defEnemy[randEnemy];
-	enemy[index].active = 1;
+	enemy[index].active = true;
 	enemy[index].face = rand() % 2;
 	enemy[index].owner = &enemy[index]; // Most enemies will own themselves
 	enemy[index].target = &enemy[index];
@@ -248,16 +251,16 @@ signed char addAlien()
 	enemy[index].deathCounter = 0 - (enemy[index].maxShield * 3);
 	enemy[index].hit = 0;
 
-	Math::limitInt(&enemy[index].deathCounter, -250, 0);
+	limitInt(&enemy[index].deathCounter, -250, 0);
 
 	// Attempts to place an alien. If it fails, the alien is deactivated.
 	for (int i = 0 ; i < 100 ; i++)
 	{
 		if (placeAlien(&enemy[index]))
 			break;
-		enemy[index].active = 0;
+		enemy[index].active = false;
 
-		return 0;
+		return false;
 	}
 
 	if (enemy[index].classDef == CD_CARGOSHIP)
@@ -269,18 +272,18 @@ signed char addAlien()
 	if (enemy[index].classDef == CD_ESCORT)
 		enemy[index].shield = 50;
 
-	enemy[index].dx = Math::rrand(-2, 2);
-	enemy[index].dy = Math::rrand(-2, 2);
+	enemy[index].dx = rrand(-2, 2);
+	enemy[index].dy = rrand(-2, 2);
 
 	enemy[index].ammo[0] = 0;
 
 	if (currentGame.area == 18)
-		enemy[index].flags += FL_HASMINIMUMSPEED;
+		enemy[index].flags |= FL_HASMINIMUMSPEED;
 
-	return 1;
+	return true;
 }
 
-void getPreDefinedAliens()
+static void getPreDefinedAliens()
 {
 	FILE *fp;
 	char string[255];
@@ -314,7 +317,7 @@ void getPreDefinedAliens()
 		enemy[index].owner = &enemy[index];
 		enemy[index].target = &enemy[index];
 		enemy[index].face = rand() % 2;
-		enemy[index].active = 1;
+		enemy[index].active = true;
 
 		/*
 		we make 1000 attempts to place this enemy since it is required. If after 1000 attempts
@@ -346,20 +349,20 @@ void getPreDefinedAliens()
 
 		if (enemy[index].classDef == CD_CLOAKFIGHTER)
 		{
-			enemy[index].active = 0;
+			enemy[index].active = false;
 			enemy[index].maxShield = enemy[index].shield = 400;
-			enemy[index].flags -= FL_RUNSAWAY;
+			enemy[index].flags &= ~FL_RUNSAWAY;
 			enemy[index].speed = 3;
 		}
 
 		if ((enemy[index].classDef == CD_MOBILE_RAY) && (index >= 11))
 		{
-			enemy[index].active = 0;
+			enemy[index].active = false;
 		}
 
 		if (enemy[index].classDef == CD_FIREFLY)
 		{
-			enemy[index].active = 0;
+			enemy[index].active = false;
 		}
 
 		if (enemy[index].classDef == CD_BARRIER)
@@ -372,11 +375,11 @@ void getPreDefinedAliens()
 		if ((currentGame.area == 17) && (enemy[index].classDef == CD_BOSS))
 		{
 			enemy[index].imageIndex[1] = 29;
-			enemy[index].flags += FL_IMMORTAL;
+			enemy[index].flags |= FL_IMMORTAL;
 		}
 
 		if (currentGame.area == 18)
-			enemy[index].flags += FL_HASMINIMUMSPEED;
+			enemy[index].flags |= FL_HASMINIMUMSPEED;
 
 		if (currentGame.area == 23)
 		{
@@ -441,8 +444,8 @@ void getPreDefinedAliens()
 				enemy[i].imageIndex[0] += 15;
 				enemy[i].imageIndex[1] += 15;
 
-				enemy[i].image[0] = graphics.shipShape[enemy[i].imageIndex[0]];
-				enemy[i].image[1] = graphics.shipShape[enemy[i].imageIndex[1]];
+				enemy[i].image[0] = shipShape[enemy[i].imageIndex[0]];
+				enemy[i].image[1] = shipShape[enemy[i].imageIndex[1]];
 			}
 		}
 	}
@@ -460,7 +463,7 @@ void getPreDefinedAliens()
 	}
 }
 
-void addFriendly(int type)
+static void addFriendly(int type)
 {
 	if (type != FR_SID)
 		enemy[type] = defEnemy[CD_FRIEND];
@@ -469,17 +472,17 @@ void addFriendly(int type)
 
 	enemy[type].owner = &enemy[type];
 	enemy[type].target = &enemy[type];
-	enemy[type].active = 1;
+	enemy[type].active = true;
 
 	if (rand() % 2 == 0)
-		enemy[type].x = Math::rrand(400, 550);
+		enemy[type].x = rrand(400, 550);
 	else
-		enemy[type].x = Math::rrand(250, 400);
+		enemy[type].x = rrand(250, 400);
 
 	if (rand() % 2 == 0)
-		enemy[type].y = Math::rrand(300, 450);
+		enemy[type].y = rrand(300, 450);
 	else
-		enemy[type].y = Math::rrand(150, 300);
+		enemy[type].y = rrand(150, 300);
 
 	if (type == FR_PHOEBE)
 		enemy[type].classDef = CD_PHOEBE;
@@ -489,7 +492,7 @@ void addFriendly(int type)
 
 	// For the sake of it being the final battle :)
 	if (currentGame.area == 25)
-		enemy[type].flags += FL_IMMORTAL;
+		enemy[type].flags |= FL_IMMORTAL;
 }
 
 void setTarget(int index)
@@ -507,7 +510,7 @@ void initAliens()
 {
 	for (int i = 0 ; i < MAX_ALIENS ; i++)
 	{
-		enemy[i].active = 0;
+		enemy[i].active = false;
 		enemy[i].shield = -1;
 		enemy[i].flags = 0;
 	}
@@ -521,7 +524,7 @@ void initAliens()
 		currentGame.hasWingMate1 = 1;
 
 	if (currentGame.area == 11)
-		enemy[WC_KLINE].active = 0;
+		enemy[WC_KLINE].active = false;
 
 	for (int i = 0 ; i < engine.maxAliens ; i++)
 		addAlien();
@@ -546,8 +549,8 @@ void initAliens()
 		case 18:
 		case 24:
 		case 26:
-			enemy[FR_PHOEBE].active = 0;
-			enemy[FR_URSULA].active = 0;
+			enemy[FR_PHOEBE].active = false;
+			enemy[FR_URSULA].active = false;
 			break;
 	}
 
@@ -566,7 +569,7 @@ void initAliens()
 			enemy[WC_KLINE].owner = &enemy[WC_KLINE];
 			enemy[WC_KLINE].target = &player;
 			enemy[WC_KLINE].shield = 100;
-			enemy[WC_KLINE].active = 1;
+			enemy[WC_KLINE].active = true;
 			enemy[WC_KLINE].x = player.x + 1000;
 			enemy[WC_KLINE].y = player.y;
 			setTarget(WC_KLINE);
@@ -580,7 +583,7 @@ void initAliens()
 				enemy[10].owner = &enemy[10];
 				enemy[10].target = &enemy[10];
 				enemy[10].shield = 1000;
-				enemy[10].active = 1;
+				enemy[10].active = true;
 				enemy[10].x = player.x - 1000;
 				enemy[10].y = player.y;
 				setTarget(10);
@@ -591,9 +594,7 @@ void initAliens()
 
 	if (currentGame.area == 26)
 	{
-		enemy[WC_KLINE].flags += FL_IMMORTAL;
-		enemy[WC_KLINE].flags += FL_NOFIRE;
-		enemy[WC_KLINE].flags += FL_NOMOVE;
+		enemy[WC_KLINE].flags |= FL_IMMORTAL | FL_NOFIRE | FL_NOMOVE;
 
 		enemy[WC_KLINE].x = 600;
 		enemy[WC_KLINE].y = 300;
@@ -607,7 +608,7 @@ void initAliens()
 	{
 		enemy[i].systemPower = enemy[i].maxShield;
 		enemy[i].deathCounter = 0 - (enemy[i].maxShield * 3);
-		Math::limitInt(&enemy[i].deathCounter, -350, 0);
+		limitInt(&enemy[i].deathCounter, -350, 0);
 	}
 
 	// Set target energy meter
@@ -649,7 +650,7 @@ void initAliens()
 "Looks" for an enemy by picking a randomly active enemy and using them
 as a target. If the target is too far away, it will be ignored.
 */
-void searchForTarget(object *theEnemy)
+static void searchForTarget(object *theEnemy)
 {
 	int i;
 
@@ -708,7 +709,7 @@ void searchForTarget(object *theEnemy)
 	theEnemy->target = targetEnemy;
 }
 
-int traceTarget(object *theEnemy)
+static int traceTarget(object *theEnemy)
 {
 	// Do various checks to see if the alien can fire at
 	// the target. Start with the most obvious checks.
@@ -751,7 +752,7 @@ int traceTarget(object *theEnemy)
 Currently only used for the allies. Whilst flying around, the allies will fire on
 any enemy craft that enter their line of sight.
 */
-int traceView(object *theEnemy)
+static int traceView(object *theEnemy)
 {
 	object *anEnemy = enemy;
 
@@ -768,23 +769,23 @@ int traceView(object *theEnemy)
 			}
 		}
 
-		*anEnemy++;
+		anEnemy++;
 	}
 
 	return 0;
 }
 
-void moveAndSeparate(object *theEnemy)
+static void moveAndSeparate(object *theEnemy)
 {
-	signed char checkCollisions = 1;
-	signed char hasCollided = 0;
+	bool checkCollisions = true;
+	bool hasCollided = false;
 
 	// don't worry about bumping into other craft
 	if ((theEnemy->flags & FL_LEAVESECTOR) || (theEnemy->classDef == CD_DRONE) || (currentGame.area == 18))
-		checkCollisions = 0;
+		checkCollisions = false;
 
 	if (theEnemy->shield < 1)
-		checkCollisions = 0;
+		checkCollisions = false;
 
 	if (theEnemy->owner == theEnemy)
 	{
@@ -801,8 +802,8 @@ void moveAndSeparate(object *theEnemy)
 				theEnemy->dy -= 0.02;
 			}
 
-			theEnemy->x -= (sin(theEnemy->dx) * 4);
-			theEnemy->y -= (cos(theEnemy->dy) * 4);
+			theEnemy->x -= (sinf(theEnemy->dx) * 4);
+			theEnemy->y -= (cosf(theEnemy->dy) * 4);
 		}
 		else
 		{
@@ -819,11 +820,11 @@ void moveAndSeparate(object *theEnemy)
 		{
 			if ((theEnemy->flags & FL_LEAVESECTOR) || (theEnemy->classDef == CD_DRONE) || (theEnemy->classDef == CD_ASTEROID2) || (theEnemy->owner == anEnemy->owner) || (theEnemy->owner->owner == anEnemy->owner) || (anEnemy->shield < 1))
 			{
-				*anEnemy++;
+				anEnemy++;
 				continue;
 			}
 
-			if (Collision::collision(theEnemy, anEnemy))
+			if (collision(theEnemy, anEnemy))
 			{
 				if ((anEnemy->classDef == CD_BARRIER) && (anEnemy->owner != theEnemy))
 				{
@@ -835,19 +836,19 @@ void moveAndSeparate(object *theEnemy)
 				}
 
 				if (anEnemy->owner == anEnemy)
-					hasCollided = 1;
+					hasCollided = true;
 			}
 
-			*anEnemy++;
+			anEnemy++;
 		}
 	}
 
 	// Handle a collision with the player
 	if ((player.shield > 0) && (theEnemy->shield > 0) && (checkCollisions))
 	{
-		if (Collision::collision(theEnemy, &player))
+		if (collision(theEnemy, &player))
 		{
-			hasCollided = 1;
+			hasCollided = true;
 
 			if (theEnemy->classDef == CD_ASTEROID)
 			{
@@ -899,8 +900,8 @@ void moveAndSeparate(object *theEnemy)
 					theEnemy->dy += 0.02;
 				}
 
-				theEnemy->x += (sin(theEnemy->dx) * 4);
-				theEnemy->y += (cos(theEnemy->dy) * 4);
+				theEnemy->x += (sinf(theEnemy->dx) * 4);
+				theEnemy->y += (cosf(theEnemy->dy) * 4);
 
 				theEnemy->thinktime = 0;
 			}
@@ -915,7 +916,7 @@ void moveAndSeparate(object *theEnemy)
 				theEnemy->dx *= 0.2;
 				theEnemy->dy *= 0.2;
 
-				Math::limitInt(&theEnemy->thinktime, 0, 15);
+				limitInt(&theEnemy->thinktime, 0, 15);
 			}
 		}
 	}
@@ -943,7 +944,7 @@ void doAliens()
 	// A global variable for checking if all the aliens are dead
 	engine.allAliensDead = 1;
 
-	signed char canFire;
+	bool canFire;
 	int shapeToUse;
 
 	object *theEnemy = enemy;
@@ -977,16 +978,16 @@ void doAliens()
 						}
 						else
 						{
-							theEnemy->flags -= FL_IMMORTAL;
+							theEnemy->flags &= ~FL_IMMORTAL;
 							theEnemy->owner = theEnemy;
 							theEnemy->chance[0] = 25;
 						}
 					}
 				}
 
-				canFire = 1; // The alien is allowed to fire
+				canFire = true; // The alien is allowed to fire
 
-				Math::limitInt(&--theEnemy->thinktime, 0, 250);
+				limitInt(&--theEnemy->thinktime, 0, 250);
 
 				if (theEnemy->target->shield < 1)
 					theEnemy->target = theEnemy;
@@ -1028,8 +1029,8 @@ void doAliens()
 						if (theEnemy->dx > 0) theEnemy->face = 1;
 					}
 
-					Math::limitFloat(&theEnemy->dx, 0 - theEnemy->speed, theEnemy->speed);
-					Math::limitFloat(&theEnemy->dy, 0 - theEnemy->speed, theEnemy->speed);
+					limitFloat(&theEnemy->dx, 0 - theEnemy->speed, theEnemy->speed);
+					limitFloat(&theEnemy->dy, 0 - theEnemy->speed, theEnemy->speed);
 
 				}
 
@@ -1047,7 +1048,7 @@ void doAliens()
 
 				if (theEnemy->flags & FL_LEAVESECTOR)
 				{
-					Math::limitFloat(&(theEnemy->dx -= 0.5), 0, -15);
+					limitFloat(&(theEnemy->dx -= 0.5), 0, -15);
 					theEnemy->dy = 0;
 					theEnemy->thinktime = 999;
 					theEnemy->face = 0;
@@ -1056,7 +1057,7 @@ void doAliens()
 					{
 						theEnemy->flags -= FL_LEAVESECTOR;
 						theEnemy->flags += FL_ESCAPED;
-						theEnemy->active = 0;
+						theEnemy->active = false;
 
 						if (theEnemy->classDef == CD_CLOAKFIGHTER)
 						{
@@ -1090,8 +1091,8 @@ void doAliens()
 
 				if (theEnemy->classDef == CD_BARRIER)
 				{
-					theEnemy->dx = -10 + (sin(barrierLoop + theEnemy->speed) * 60);
-					theEnemy->dy = 20 + (cos(barrierLoop + theEnemy->speed) * 40);
+					theEnemy->dx = -10 + (sinf(barrierLoop + theEnemy->speed) * 60);
+					theEnemy->dy = 20 + (cosf(barrierLoop + theEnemy->speed) * 40);
 				}
 
 				// ----------------------------------------
@@ -1100,13 +1101,13 @@ void doAliens()
 
 				if (theEnemy->classDef == CD_MOBILESHIELD)
 				{
-					Math::limitInt(&(++enemy[WC_BOSS].shield), 0, enemy[WC_BOSS].maxShield);
+					limitInt(&(++enemy[WC_BOSS].shield), 0, enemy[WC_BOSS].maxShield);
 				}
 
 				// ----------------------------------------
 
-				Math::limitChar(&--theEnemy->reload[0], 0, 999);
-				Math::limitChar(&--theEnemy->reload[1], 0, 999);
+				limitCharAdd(&theEnemy->reload[0], -1, 0, 999);
+				limitCharAdd(&theEnemy->reload[1], -1, 0, 999);
 
     			if ((!(theEnemy->flags & FL_DISABLED)) && (!(theEnemy->flags & FL_NOFIRE)))
 				{
@@ -1118,10 +1119,10 @@ void doAliens()
 				}
 				else
 				{
-					canFire = 0;
+					canFire = false;
 				}
 
-				if ((canFire == 1) && (dev.fireAliens))
+				if ((canFire) && (dev.fireAliens))
 				{
 					if ((theEnemy->reload[0] == 0) && ((rand() % 1000 < theEnemy->chance[0]) || (theEnemy->flags & FL_CONTINUOUS_FIRE)))
 					{
@@ -1154,7 +1155,7 @@ void doAliens()
 				}
 				else
 				{
-					Math::limitChar(&++theEnemy->ammo[0], 0, 250);
+					limitCharAdd(&theEnemy->ammo[0], 1, 0, 250);
 				}
 				// -------------------------------------------------------
 
@@ -1185,14 +1186,14 @@ void doAliens()
 				if (theEnemy->hit)
 					shapeToUse += SHIP_HIT_INDEX;
 
-				Math::limitChar(&--theEnemy->hit, 0, 100);
+				limitCharAdd(&theEnemy->hit, -1, 0, 100);
 
 				if ((theEnemy->x + theEnemy->image[0]->w > 0) && (theEnemy->x < 800) && (theEnemy->y + theEnemy->image[0]->h > 0) && (theEnemy->y < 600))
 				{
 					if ((!(theEnemy->flags & FL_DISABLED)) && (theEnemy->classDef != CD_ASTEROID) && (theEnemy->classDef != CD_ASTEROID2))
 						addEngine(theEnemy);
 					if ((!(theEnemy->flags & FL_ISCLOAKED)) || (theEnemy->hit > 0))
-						graphics.blit(graphics.shipShape[shapeToUse], (int)theEnemy->x, (int)theEnemy->y);
+						blit(shipShape[shapeToUse], (int)theEnemy->x, (int)theEnemy->y);
 					if (theEnemy->flags & FL_DISABLED)
 					{
 						if ((rand() % 10) == 0)
@@ -1201,19 +1202,19 @@ void doAliens()
 				}
 
 				if ((currentGame.area == 24) && (theEnemy->x < -300))
-					theEnemy->active = 0;
+					theEnemy->active = false;
 			}
 			else
 			{
 				theEnemy->shield--;
 				if ((theEnemy->x > 0) && (theEnemy->x < 800) && (theEnemy->y > 0) && (theEnemy->y < 600))
 				{
-					graphics.blit(theEnemy->image[theEnemy->face], (int)theEnemy->x, (int)theEnemy->y);
+					blit(theEnemy->image[theEnemy->face], (int)theEnemy->x, (int)theEnemy->y);
 					addExplosion(theEnemy->x + (rand() % theEnemy->image[0]->w), theEnemy->y + (rand() % theEnemy->image[0]->h), E_BIG_EXPLOSION);
 				}
 				if (theEnemy->shield < theEnemy->deathCounter)
 				{
-					theEnemy->active = 0;
+					theEnemy->active = false;
 					if ((theEnemy->classDef == CD_BOSS) || (theEnemy->owner == &enemy[WC_BOSS]) || (theEnemy->flags & FL_FRIEND) || (theEnemy->classDef == CD_ASTEROID) || (theEnemy->classDef == CD_KLINE))
 						addDebris((int)theEnemy->x, (int)theEnemy->y, theEnemy->maxShield);
 
@@ -1238,7 +1239,7 @@ void doAliens()
 			theEnemy->y += engine.ssy;
 		}
 
-		*theEnemy++;
+		theEnemy++;
 	}
 }
 
@@ -1246,10 +1247,10 @@ void setAlienShapes()
 {
 	for (int i = 0 ; i < MAX_DEFALIENS ; i++)
 	{
-		if (graphics.shipShape[defEnemy[i].imageIndex[0]] != NULL)
+		if (shipShape[defEnemy[i].imageIndex[0]] != NULL)
 		{
-			defEnemy[i].image[0] = graphics.shipShape[defEnemy[i].imageIndex[0]];
-			defEnemy[i].image[1] = graphics.shipShape[defEnemy[i].imageIndex[1]];
+			defEnemy[i].image[0] = shipShape[defEnemy[i].imageIndex[0]];
+			defEnemy[i].image[1] = shipShape[defEnemy[i].imageIndex[1]];
 			defEnemy[i].engineX = defEnemy[i].image[0]->w;
 			defEnemy[i].engineY = (defEnemy[i].image[0]->h / 2);
 		}
@@ -1258,7 +1259,7 @@ void setAlienShapes()
 
 #if USEPACK
 
-void loadAliens()
+static void loadAliens()
 {
 	int dataLocation = locateDataInPak("data/aliens.dat", 1);
 	int def, ai, speed, shield, max, image1, image2, weapon1, weapon2, chance1, chance2, score;
@@ -1313,7 +1314,7 @@ void defineAliens(){loadAliens();}
 
 #else
 
-void saveAliens()
+static void saveAliens()
 {
 	FILE *fp;
 
@@ -1460,7 +1461,7 @@ void defineAliens()
 	defEnemy[CD_FRIGATE_WING1].collectChance = 100;
 	defEnemy[CD_FRIGATE_WING1].collectType = P_ANYTHING;
 	defEnemy[CD_FRIGATE_WING1].collectValue = 250;
-	defEnemy[CD_FRIGATE_WING1].flags = FL_WEAPCO + FL_DAMAGEOWNER;
+	defEnemy[CD_FRIGATE_WING1].flags = FL_WEAPCO | FL_DAMAGEOWNER;
 
 	defEnemy[CD_FRIGATE_WING2].classDef = CD_FRIGATE_WING2;
 	defEnemy[CD_FRIGATE_WING2].AIType = AI_NORMAL;
@@ -1477,7 +1478,7 @@ void defineAliens()
 	defEnemy[CD_FRIGATE_WING2].collectChance = 100;
 	defEnemy[CD_FRIGATE_WING2].collectType = P_ANYTHING;
 	defEnemy[CD_FRIGATE_WING2].collectValue = 250;
-	defEnemy[CD_FRIGATE_WING2].flags = FL_WEAPCO + FL_DAMAGEOWNER;
+	defEnemy[CD_FRIGATE_WING2].flags = FL_WEAPCO | FL_DAMAGEOWNER;
 
 	// Transport ship
 	defEnemy[CD_TRANSPORTSHIP].classDef = CD_TRANSPORTSHIP;
@@ -1495,7 +1496,7 @@ void defineAliens()
 	defEnemy[CD_TRANSPORTSHIP].collectChance = 100;
 	defEnemy[CD_TRANSPORTSHIP].collectType = P_WEAPONS;
 	defEnemy[CD_TRANSPORTSHIP].collectValue = 30;
-	defEnemy[CD_TRANSPORTSHIP].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_TRANSPORTSHIP].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Cargo ship
 	defEnemy[CD_CARGOSHIP].classDef = CD_CARGOSHIP;
@@ -1513,7 +1514,7 @@ void defineAliens()
 	defEnemy[CD_CARGOSHIP].collectChance = 50;
 	defEnemy[CD_CARGOSHIP].collectType = P_ANYTHING;
 	defEnemy[CD_CARGOSHIP].collectValue = 100;
-	defEnemy[CD_CARGOSHIP].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_CARGOSHIP].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Weapco Miner
 	defEnemy[CD_MINER].classDef = CD_MINER;
@@ -1531,7 +1532,7 @@ void defineAliens()
 	defEnemy[CD_MINER].collectChance = 100;
 	defEnemy[CD_MINER].collectType = P_ANYTHING;
 	defEnemy[CD_MINER].collectValue = 30;
-	defEnemy[CD_MINER].flags = FL_WEAPCO + FL_NOFIRE + FL_DROPMINES;
+	defEnemy[CD_MINER].flags = FL_WEAPCO | FL_NOFIRE | FL_DROPMINES;
 
 	// Kline
 	defEnemy[CD_KLINE].classDef = CD_KLINE;
@@ -1549,7 +1550,7 @@ void defineAliens()
 	defEnemy[CD_KLINE].collectChance = 0;
 	defEnemy[CD_KLINE].collectType = P_ANYTHING;
 	defEnemy[CD_KLINE].collectValue = 0;
-	defEnemy[CD_KLINE].flags = FL_WEAPCO + FL_CANNOTDIE + FL_ALWAYSFACE + FL_CIRCLES;
+	defEnemy[CD_KLINE].flags = FL_WEAPCO | FL_CANNOTDIE | FL_ALWAYSFACE | FL_CIRCLES;
 
 	// Aim Fighter
 	defEnemy[CD_AIMFIGHTER].classDef = CD_AIMFIGHTER;
@@ -1567,7 +1568,7 @@ void defineAliens()
 	defEnemy[CD_AIMFIGHTER].collectChance = 75;
 	defEnemy[CD_AIMFIGHTER].collectType = P_ANYTHING;
 	defEnemy[CD_AIMFIGHTER].collectValue = 100;
-	defEnemy[CD_AIMFIGHTER].flags = FL_WEAPCO + FL_AIMS;
+	defEnemy[CD_AIMFIGHTER].flags = FL_WEAPCO | FL_AIMS;
 
 	// Slave ship
 	defEnemy[CD_SLAVETRANSPORT].classDef = CD_SLAVETRANSPORT;
@@ -1585,7 +1586,7 @@ void defineAliens()
 	defEnemy[CD_SLAVETRANSPORT].collectChance = 100;
 	defEnemy[CD_SLAVETRANSPORT].collectType = P_SLAVES;
 	defEnemy[CD_SLAVETRANSPORT].collectValue = 25;
-	defEnemy[CD_SLAVETRANSPORT].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_SLAVETRANSPORT].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Good Transport
 	defEnemy[CD_GOODTRANSPORT].classDef = CD_GOODTRANSPORT;
@@ -1603,7 +1604,7 @@ void defineAliens()
 	defEnemy[CD_GOODTRANSPORT].collectChance = 0;
 	defEnemy[CD_GOODTRANSPORT].collectType = P_ANYTHING;
 	defEnemy[CD_GOODTRANSPORT].collectValue = 0;
-	defEnemy[CD_GOODTRANSPORT].flags = FL_FRIEND + FL_NOFIRE + FL_AIMS;
+	defEnemy[CD_GOODTRANSPORT].flags = FL_FRIEND | FL_NOFIRE | FL_AIMS;
 
 	// Sid Wilson
 	defEnemy[CD_SID].classDef = CD_SID;
@@ -1621,7 +1622,7 @@ void defineAliens()
 	defEnemy[CD_SID].collectChance = 0;
 	defEnemy[CD_SID].collectType = P_ANYTHING;
 	defEnemy[CD_SID].collectValue = 0;
-	defEnemy[CD_SID].flags = FL_FRIEND + FL_AIMS;
+	defEnemy[CD_SID].flags = FL_FRIEND | FL_AIMS;
 
 	// Mining Vessel Boss
 	defEnemy[CD_MINEBOSS].classDef = CD_BOSS;
@@ -1639,7 +1640,7 @@ void defineAliens()
 	defEnemy[CD_MINEBOSS].collectChance = 100;
 	defEnemy[CD_MINEBOSS].collectType = P_ANYTHING;
 	defEnemy[CD_MINEBOSS].collectValue = 255;
-	defEnemy[CD_MINEBOSS].flags = FL_WEAPCO + FL_IMMORTAL;
+	defEnemy[CD_MINEBOSS].flags = FL_WEAPCO | FL_IMMORTAL;
 
 	defEnemy[CD_BOSS2_WING1].classDef = CD_BOSS2_WING1;
 	defEnemy[CD_BOSS2_WING1].AIType = AI_NORMAL;
@@ -1656,7 +1657,7 @@ void defineAliens()
 	defEnemy[CD_BOSS2_WING1].collectChance = 100;
 	defEnemy[CD_BOSS2_WING1].collectType = P_ANYTHING;
 	defEnemy[CD_BOSS2_WING1].collectValue = 255;
-	defEnemy[CD_BOSS2_WING1].flags = FL_WEAPCO + FL_DAMAGEOWNER;
+	defEnemy[CD_BOSS2_WING1].flags = FL_WEAPCO | FL_DAMAGEOWNER;
 
 	defEnemy[CD_BOSS2_WING2].classDef = CD_BOSS2_WING2;
 	defEnemy[CD_BOSS2_WING2].AIType = AI_NORMAL;
@@ -1673,7 +1674,7 @@ void defineAliens()
 	defEnemy[CD_BOSS2_WING2].collectChance = 100;
 	defEnemy[CD_BOSS2_WING2].collectType = P_ANYTHING;
 	defEnemy[CD_BOSS2_WING2].collectValue = 255;
-	defEnemy[CD_BOSS2_WING2].flags = FL_WEAPCO + FL_DEPLOYDRONES + FL_DAMAGEOWNER;
+	defEnemy[CD_BOSS2_WING2].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER;
 
 	defEnemy[CD_BOSS2_WING3].classDef = CD_BOSS2_WING3;
 	defEnemy[CD_BOSS2_WING3].AIType = AI_NORMAL;
@@ -1690,7 +1691,7 @@ void defineAliens()
 	defEnemy[CD_BOSS2_WING3].collectChance = 100;
 	defEnemy[CD_BOSS2_WING3].collectType = P_ANYTHING;
 	defEnemy[CD_BOSS2_WING3].collectValue = 255;
-	defEnemy[CD_BOSS2_WING3].flags = FL_WEAPCO + FL_DEPLOYDRONES + FL_DAMAGEOWNER;
+	defEnemy[CD_BOSS2_WING3].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER;
 
 	defEnemy[CD_BOSS2_WING4].classDef = CD_BOSS2_WING4;
 	defEnemy[CD_BOSS2_WING4].AIType = AI_NORMAL;
@@ -1707,7 +1708,7 @@ void defineAliens()
 	defEnemy[CD_BOSS2_WING4].collectChance = 100;
 	defEnemy[CD_BOSS2_WING4].collectType = P_ANYTHING;
 	defEnemy[CD_BOSS2_WING4].collectValue = 255;
-	defEnemy[CD_BOSS2_WING4].flags = FL_WEAPCO + FL_DAMAGEOWNER;
+	defEnemy[CD_BOSS2_WING4].flags = FL_WEAPCO | FL_DAMAGEOWNER;
 
 	// Drone
 	defEnemy[CD_DRONE].classDef = CD_DRONE;
@@ -1743,7 +1744,7 @@ void defineAliens()
 	defEnemy[CD_CLOAKFIGHTER].collectChance = 100;
 	defEnemy[CD_CLOAKFIGHTER].collectType = P_CASH;
 	defEnemy[CD_CLOAKFIGHTER].collectValue = 255;
-	defEnemy[CD_CLOAKFIGHTER].flags = FL_WEAPCO + FL_CANCLOAK + FL_RUNSAWAY;
+	defEnemy[CD_CLOAKFIGHTER].flags = FL_WEAPCO | FL_CANCLOAK | FL_RUNSAWAY;
 
 	// Evil Ursula
 	defEnemy[CD_EVILURSULA].classDef = CD_EVILURSULA;
@@ -1779,7 +1780,7 @@ void defineAliens()
 	defEnemy[CD_KRASS].collectChance = 100;
 	defEnemy[CD_KRASS].collectType = P_ANYTHING;
 	defEnemy[CD_KRASS].collectValue = 255;
-	defEnemy[CD_KRASS].flags = FL_FRIEND + FL_IMMORTAL;
+	defEnemy[CD_KRASS].flags = FL_FRIEND | FL_IMMORTAL;
 
 	// Executive Transport
 	defEnemy[CD_EXEC].classDef = CD_BOSS;
@@ -1797,7 +1798,7 @@ void defineAliens()
 	defEnemy[CD_EXEC].collectChance = 0;
 	defEnemy[CD_EXEC].collectType = P_ANYTHING;
 	defEnemy[CD_EXEC].collectValue = 0;
-	defEnemy[CD_EXEC].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_EXEC].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Asteroid
 	defEnemy[CD_ASTEROID].classDef = CD_ASTEROID;
@@ -1922,7 +1923,7 @@ void defineAliens()
 	defEnemy[CD_BARRIER].collectChance = 100;
 	defEnemy[CD_BARRIER].collectType = P_ANYTHING;
 	defEnemy[CD_BARRIER].collectValue = 25;
-	defEnemy[CD_BARRIER].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_BARRIER].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Neptune Boss
 	defEnemy[CD_NEPTUNEBOSS].classDef = CD_NEPTUNEBOSS;
@@ -1958,7 +1959,7 @@ void defineAliens()
 	defEnemy[CD_MOBILESHIELD].collectChance = 100;
 	defEnemy[CD_MOBILESHIELD].collectType = P_ANYTHING;
 	defEnemy[CD_MOBILESHIELD].collectValue = 25;
-	defEnemy[CD_MOBILESHIELD].flags = FL_WEAPCO + FL_NOFIRE;
+	defEnemy[CD_MOBILESHIELD].flags = FL_WEAPCO | FL_NOFIRE;
 
 	// Firefly
 	defEnemy[CD_FIREFLY].classDef = CD_FIREFLY;
@@ -2012,7 +2013,7 @@ void defineAliens()
 	defEnemy[CD_URANUSBOSSWING1].collectChance = 100;
 	defEnemy[CD_URANUSBOSSWING1].collectType = P_ANYTHING;
 	defEnemy[CD_URANUSBOSSWING1].collectValue = 250;
-	defEnemy[CD_URANUSBOSSWING1].flags = FL_WEAPCO + FL_IMMORTAL;
+	defEnemy[CD_URANUSBOSSWING1].flags = FL_WEAPCO | FL_IMMORTAL;
 
 	// Uranus Boss Wing 2
 	defEnemy[CD_URANUSBOSSWING2].classDef = CD_URANUSBOSSWING2;
@@ -2030,7 +2031,7 @@ void defineAliens()
 	defEnemy[CD_URANUSBOSSWING2].collectChance = 100;
 	defEnemy[CD_URANUSBOSSWING2].collectType = P_ANYTHING;
 	defEnemy[CD_URANUSBOSSWING2].collectValue = 250;
-	defEnemy[CD_URANUSBOSSWING2].flags = FL_WEAPCO + FL_IMMORTAL;
+	defEnemy[CD_URANUSBOSSWING2].flags = FL_WEAPCO | FL_IMMORTAL;
 
 	saveAliens();
 }
