@@ -18,19 +18,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-
-extern void unpack(char *file, signed char fileType);
-extern void freePackBuffer();
-
-extern globalEngineVariables engine;
-extern Game currentGame;
 extern Mix_Chunk *sound[MAX_SOUNDS];
+
+extern void playSound(int sid);
+extern Mix_Chunk *loadSound(const char *filename);
+extern void loadMusic(const char *filename);
+extern void playRandomTrack();
