@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "bullets.h"
+#include "Starfighter.h"
 
 void addBullet(object *theWeapon, object *attacker, int y, int dy)
 {
@@ -32,7 +32,7 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 		currentGame.shots++;
 
 	bullet->next = NULL;
-	bullet->active = 1;
+	bullet->active = true;
 	bullet->x = attacker->x - ((attacker->image[0]->w / 2) * attacker->face);
 	bullet->y = attacker->y + y;
 	bullet->flags = theWeapon->flags;
@@ -46,7 +46,7 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 	{
 		bullet->dx = theWeapon->speed;
 		if ((currentGame.area == 18) || (currentGame.area == 24))
-			bullet->dx += fabs(engine.ssx);
+			bullet->dx += fabsf(engine.ssx);
 	}
 	else
 	{
@@ -55,7 +55,7 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 
 	if (bullet->flags & WF_VARIABLE_SPEED)
 	{
-		bullet->dx = Math::rrand(100, 200);
+		bullet->dx = rrand(100, 200);
 		bullet->dx /= 10;
 		if (attacker->face == 1)
 			bullet->dx = 0 - bullet->dx;
@@ -65,15 +65,15 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 
 	if (bullet->flags & WF_SCATTER)
 	{
-		bullet->dy = Math::rrand(-200, 200);
+		bullet->dy = rrand(-200, 200);
 		if (bullet->dy != 0)
 			bullet->dy /= 200;
 	}
 
 	if (attacker->flags & FL_WEAPCO)
-		bullet->flags += WF_WEAPCO;
+		bullet->flags |= WF_WEAPCO;
 	else
-		bullet->flags += WF_FRIEND;
+		bullet->flags |= WF_FRIEND;
 
 	bullet->owner = attacker->owner;
 
@@ -106,11 +106,11 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 
 	if (bullet->flags & WF_AIMED)
 	{
-		tempX = (int)fabs(attacker->target->x - attacker->x);
-		tempY = (int)fabs(attacker->target->y - attacker->y);
+		tempX = (int)fabsf(attacker->target->x - attacker->x);
+		tempY = (int)fabsf(attacker->target->y - attacker->y);
 		steps = max(tempX, tempY);
 
-		if (steps == 0)
+		if (steps < 12)
 			steps = 12;
 
 		if (!(bullet->flags & WF_TIMEDEXPLOSION))
@@ -127,9 +127,9 @@ void addBullet(object *theWeapon, object *attacker, int y, int dy)
 
 	if (attacker->classDef == CD_ASTEROID)
 	{
-		bullet->dx = Math::rrand(-20, 20);
-		bullet->dy = Math::rrand(-20, 20);
-		bullet->image[0] = graphics.shape[4];
+		bullet->dx = rrand(-20, 20);
+		bullet->dy = rrand(-20, 20);
+		bullet->image[0] = shape[4];
 	}
 
 	engine.bulletTail->next = bullet;
@@ -170,55 +170,37 @@ void fireBullet(object *attacker, int weaponType)
 			break;
 	}
 
-	if (theWeapon->flags & WF_STRAIGHT)
+	if (theWeapon->flags & WF_SPREAD && theWeapon->ammo[0] >= 3)
 	{
-		switch (theWeapon->ammo[0])
-		{
-			case 1:
-				addBullet(theWeapon, attacker, y * 3, 0);
-				break;
-			case 2:
-				addBullet(theWeapon, attacker, y * 2, 0);
-				addBullet(theWeapon, attacker, y * 4, 0);
-				break;
-			case 3:
-				addBullet(theWeapon, attacker, y * 2, 0);
-				addBullet(theWeapon, attacker, y * 3, 0);
-				addBullet(theWeapon, attacker, y * 4, 0);
-				break;
-			case 4:
-				addBullet(theWeapon, attacker, y, 0);
-				addBullet(theWeapon, attacker, y * 2, 0);
-				addBullet(theWeapon, attacker, y * 4, 0);
-				addBullet(theWeapon, attacker, y * 5, 0);
-				break;
-			case 5:
-				for (int i = 1 ; i < 6; i++)
-					addBullet(theWeapon, attacker, y * i, 0);
-				break;
-		}
-	}
-	else if (theWeapon->flags & WF_THIN_SPREAD)
-	{
-		addBullet(theWeapon, attacker, y * 2, -1);
-		if (theWeapon->ammo[0] == 3)
-		{
+		addBullet(theWeapon, attacker, y * 1, -2);
+
+		if(theWeapon->ammo[0] != 4)
 			addBullet(theWeapon, attacker, y * 3, 0);
+
+		if(theWeapon->ammo[0] != 3)
+		{
+			addBullet(theWeapon, attacker, y * 2, -1);
+			addBullet(theWeapon, attacker, y * 4, 1);
 		}
-		else
+
+		addBullet(theWeapon, attacker, y * 5, 2);
+	}
+	else
+	{
+		if(theWeapon->ammo[0] & 1)
+			addBullet(theWeapon, attacker, y * 3, 0);
+
+		if(theWeapon->ammo[0] >= 2)
 		{
 			addBullet(theWeapon, attacker, y * 2, 0);
 			addBullet(theWeapon, attacker, y * 4, 0);
 		}
-		addBullet(theWeapon, attacker, y * 4, 1);
-	}
-	else if (theWeapon->flags & WF_WIDE_SPREAD)
-	{
-		addBullet(theWeapon, attacker, y * 1, -2);
-		addBullet(theWeapon, attacker, y * 2, -1);
-		addBullet(theWeapon, attacker, y * 3, 0);
-		addBullet(theWeapon, attacker, y * 4, 1);
-		addBullet(theWeapon, attacker, y * 5, 2);
+
+		if(theWeapon->ammo[0] >= 4)
+		{
+			addBullet(theWeapon, attacker, y * 1, 0);
+			addBullet(theWeapon, attacker, y * 5, 0);
+		}
 	}
 
 	// Reset the weapon reload time. Double it if it is not friendly or a boss or Kline
@@ -236,8 +218,9 @@ void fireBullet(object *attacker, int weaponType)
 			player.ammo[0]--;
 			if (player.ammo[0] == 0)
 			{
-				player.weaponType[0] = W_PLAYER_WEAPON;
-				weapon[W_PLAYER_WEAPON2] = weapon[W_PLAYER_WEAPON]; // reset to weapon 1 defaults
+				weapon[0].ammo[0] = currentGame.minPlasmaOutput;
+				weapon[0].damage = currentGame.minPlasmaDamage;
+				weapon[0].reload[0] = rate2reload[currentGame.minPlasmaRate];
 			}
 		}
 	}
@@ -252,7 +235,7 @@ one attempt per call (one call per frame) to find a suitable target. If the targ
 it picks is dead or outside the screen range, then it returns NULL. A suitable
 target will be returned as the object address.
 */
-object *getRandomEnemy(object *bullet)
+static object *getRandomEnemy(object *bullet)
 {
 	int i;
 
@@ -287,7 +270,7 @@ object *getRandomEnemy(object *bullet)
 /*
 Fill in later...
 */
-void destroyAlien(object *bullet, object *theEnemy)
+static void destroyAlien(object *bullet, object *theEnemy)
 {
 	playSound(SFX_EXPLOSION);
 
@@ -312,7 +295,7 @@ void destroyAlien(object *bullet, object *theEnemy)
 			if ((theEnemy->classDef == CD_PHOEBE) || (theEnemy->classDef == CD_URSULA))
 				setInfoLine(">> Ally has ejected! <<\n", FONT_RED);
 			else
-				setInfoLine(">> Friendly craft has been destroy!! <<\n", FONT_RED);
+				setInfoLine(">> Friendly craft has been destroyed!! <<\n", FONT_RED);
 		}
 	}
 
@@ -385,15 +368,15 @@ void destroyAlien(object *bullet, object *theEnemy)
 	}
 }
 
-char checkPlayerShockDamage(float x, float y, int radius)
+char checkPlayerShockDamage(float x, float y)
 {
 	// Don't let the player be hurt by an explosion after they have completed
 	// all the mission objectives. That would be *really* annoying!
 	if ((engine.cheatShield) || (engine.missionCompleteTimer != 0))
 		return 0;
 
-	float distX = fabs(x - player.x);
-	float distY = fabs(y - player.y);
+	float distX = fabsf(x - player.x);
+	float distY = fabsf(y - player.y);
 
 	if ((distX <= 50) && (distY <= 50))
 	{
@@ -405,7 +388,7 @@ char checkPlayerShockDamage(float x, float y, int radius)
 
 		player.shield -= (int)(10 - distX);
 		player.shield -= (int)(10 - distY);
-		Math::limitInt(&player.shield, 0, player.maxShield);
+		limitInt(&player.shield, 0, player.maxShield);
 		player.hit = 10;
 
 		return 1;
@@ -433,15 +416,15 @@ void fireRay(object *attacker)
 	ray.h = 3;
 	ray.w = 800;
 
-	int red = SDL_MapRGB(graphics.screen->format, rand() % 256, 0x00, 0x00);
-	SDL_FillRect(graphics.screen, &ray, red);
-	graphics.addBuffer(ray.x, ray.y, ray.w, ray.h);
+	int red = SDL_MapRGB(screen->format, rand() % 256, 0x00, 0x00);
+	SDL_FillRect(screen, &ray, red);
+	addBuffer(ray.x, ray.y, ray.w, ray.h);
 
 	if (attacker != &player)
 	{
 		if (player.shield > 0)
 		{
-			if (Collision::collision(player.x, player.y, player.image[0]->w, player.image[0]->h, ray.x, ray.y, ray.w, ray.h) && (!engine.cheatShield))
+			if (collision(player.x, player.y, player.image[0]->w, player.image[0]->h, ray.x, ray.y, ray.w, ray.h) && (!engine.cheatShield))
 			{
 				if (player.shield > engine.lowShield)
 				{
@@ -472,7 +455,7 @@ void fireRay(object *attacker)
 
 		if ((anEnemy->shield > 0) && (attacker != anEnemy) && (attacker->classDef != anEnemy->classDef))
 		{
-			if (Collision::collision(anEnemy->x, anEnemy->y, anEnemy->image[0]->w, anEnemy->image[0]->h, ray.x, ray.y, ray.w, ray.h))
+			if (collision(anEnemy->x, anEnemy->y, anEnemy->image[0]->w, anEnemy->image[0]->h, ray.x, ray.y, ray.w, ray.h))
 			{
 				anEnemy->shield--;
 				addExplosion(anEnemy->x, anEnemy->y, E_SMALL_EXPLOSION);
@@ -484,12 +467,12 @@ void fireRay(object *attacker)
 			}
 		}
 
-		*anEnemy++;
+		anEnemy++;
 	}
 
 	attacker->ammo[0]--;
 	if (attacker->ammo[0] < 1)
-		attacker->flags -= FL_FIRERAY;
+		attacker->flags &= ~FL_FIRERAY;
 }
 
 /*
@@ -510,14 +493,14 @@ void doBullets()
 
 	object *theEnemy, *theCargo;
 
-	signed char okayToHit = 0;
+	bool okayToHit = false;
 	float homingMissileSpeed = 0;
 
 	while (bullet->next != NULL)
 	{
 		bullet = bullet->next;
 
-		if (bullet->active == 1)
+		if (bullet->active)
 		{
 			if (bullet->flags & WF_HOMING)
 			{
@@ -539,36 +522,36 @@ void doBullets()
 				addExplosion(bullet->x, bullet->y, E_TINY_EXPLOSION);
 			}
 
-			if ((bullet->flags & WF_AIMED) || (bullet->flags & WF_THIN_SPREAD))
+			if ((bullet->flags & WF_AIMED))
 			{
-				graphics.blit(bullet->image[0], (int)(bullet->x - bullet->dx), (int)(bullet->y - bullet->dy));
+				blit(bullet->image[0], (int)(bullet->x - bullet->dx), (int)(bullet->y - bullet->dy));
 			}
 
 			if (bullet->id == WT_CHARGER)
 			{
 				for (int i = 0 ; i < bullet->damage ; i++)
-					graphics.blit(bullet->image[0], (int)(bullet->x - Math::rrand(-(bullet->damage / 3), 0)), (int)(bullet->y + Math::rrand(-3, 3)));
+					blit(bullet->image[0], (int)(bullet->x - rrand(-(bullet->damage / 3), 0)), (int)(bullet->y + rrand(-3, 3)));
 			}
 
-			graphics.blit(bullet->image[0], (int)bullet->x, (int)bullet->y);
+			blit(bullet->image[0], (int)bullet->x, (int)bullet->y);
 			bullet->x += bullet->dx;
 			bullet->y += bullet->dy;
 
 			if (bullet->target != NULL)
 			{
 				if (bullet->x < bullet->target->x)
-					Math::limitFloat(&(bullet->dx += homingMissileSpeed), -15, 15);
+					limitFloat(&(bullet->dx += homingMissileSpeed), -15, 15);
 				if (bullet->x > bullet->target->x)
-					Math::limitFloat(&(bullet->dx -= homingMissileSpeed), -15, 15);
+					limitFloat(&(bullet->dx -= homingMissileSpeed), -15, 15);
 
 				//Rocket is (more or less) inline with target. Fly straight
 				if ((bullet->x > bullet->target->x - 1) && (bullet->x < bullet->target->x + 5))
 					bullet->dx = 0;
 
 				if (bullet->y < bullet->target->y)
-					Math::limitFloat(&(bullet->dy += homingMissileSpeed), -15, 15);
+					limitFloat(&(bullet->dy += homingMissileSpeed), -15, 15);
 				if (bullet->y > bullet->target->y)
-					Math::limitFloat(&(bullet->dy -= homingMissileSpeed), -15, 15);
+					limitFloat(&(bullet->dy -= homingMissileSpeed), -15, 15);
 
 				//Rocket is (more or less) inline with target. Fly straight
 				if ((bullet->y > bullet->target->y - 1) && (bullet->y < bullet->target->y + 5))
@@ -588,21 +571,21 @@ void doBullets()
 				if ((theEnemy->shield < 1) || (!theEnemy->active))
 					continue;
 
-				okayToHit = 0;
+				okayToHit = false;
 
 				if ((bullet->flags & WF_FRIEND) && (theEnemy->flags & FL_WEAPCO))
-					okayToHit = 1;
+					okayToHit = true;
 				if ((bullet->flags & WF_WEAPCO) && (theEnemy->flags & FL_FRIEND))
-					okayToHit = 1;
+					okayToHit = true;
 				if ((bullet->id == WT_ROCKET) || (bullet->id == WT_LASER) || (bullet->id == WT_CHARGER))
-					okayToHit = 1;
+					okayToHit = true;
 
 				if (bullet->owner == theEnemy->owner)
-					okayToHit = 0;
+					okayToHit = false;
 
 				if (okayToHit)
 				{
-					if ((bullet->active == 1) && (Collision::collision(bullet, theEnemy)))
+					if ((bullet->active) && (collision(bullet, theEnemy)))
 					{
 						if (bullet->owner == &player)
 						{
@@ -623,16 +606,15 @@ void doBullets()
 
 						if (theEnemy->flags & FL_CANNOTDIE)
 						{
-							Math::limitInt(&theEnemy->shield, 1, theEnemy->maxShield);
+							limitInt(&theEnemy->shield, 1, theEnemy->maxShield);
 							if (theEnemy->shield == 1)
 							{
 								if (currentGame.area != 26)
 								{
 									if (!(theEnemy->flags & FL_LEAVESECTOR))
 									{
-										theEnemy->flags += FL_LEAVESECTOR;
-										if (theEnemy->flags & FL_CIRCLES)
-											theEnemy->flags -= FL_CIRCLES;
+										theEnemy->flags |= FL_LEAVESECTOR;
+										theEnemy->flags &= ~FL_CIRCLES;
 										if (currentGame.area == 11)
 											setRadioMessage(FACE_KLINE, "Seems I underestimated you, Bainfield! We'll meet again!", 1);
 										else if (currentGame.area == 25)
@@ -648,20 +630,19 @@ void doBullets()
 
 						if ((theEnemy->flags & FL_RUNSAWAY) && ((rand() % 50) == 0))
 						{
-							if (!(theEnemy->flags & FL_LEAVESECTOR))
-								theEnemy->flags += FL_LEAVESECTOR;
+							theEnemy->flags |= FL_LEAVESECTOR;
 						}
 
 						if (bullet->id != WT_CHARGER)
 						{
-							bullet->active = 0;
+							bullet->active = false;
 							bullet->shield = 0;
 						}
 						else if (bullet->id == WT_CHARGER)
 						{
 							bullet->shield -= theEnemy->shield;
 							if (bullet->shield < 0)
-								bullet->active = 0;
+								bullet->active = false;
 						}
 
 						playSound(SFX_HIT);
@@ -695,7 +676,7 @@ void doBullets()
 			// Check for bullets hitting player
 			if ((bullet->flags & WF_WEAPCO) || (bullet->id == WT_ROCKET) || (bullet->id == WT_LASER) || (bullet->id == WT_CHARGER))
 			{
-				if ((bullet->active == 1) && (player.shield > 0) && (Collision::collision(bullet, &player)) && (bullet->owner != &player))
+				if ((bullet->active) && (player.shield > 0) && (collision(bullet, &player)) && (bullet->owner != &player))
 				{
 					if ((!engine.cheatShield) || (engine.missionCompleteTimer != 0))
 					{
@@ -707,7 +688,7 @@ void doBullets()
 							}
 						}
 						player.shield -= bullet->damage;
-						Math::limitInt(&player.shield, 0, player.maxShield);
+						limitInt(&player.shield, 0, player.maxShield);
 						player.hit = 5;
 					}
 
@@ -716,14 +697,14 @@ void doBullets()
 
 					if (bullet->id != WT_CHARGER)
 					{
-						bullet->active = 0;
+						bullet->active = false;
 						bullet->shield = 0;
 					}
 					else if (bullet->id == WT_CHARGER)
 					{
 						bullet->shield -= theEnemy->shield;
 						if (bullet->shield < 0)
-							bullet->active = 0;
+							bullet->active = false;
 					}
 
 					playSound(SFX_HIT);
@@ -743,17 +724,17 @@ void doBullets()
 				theCargo = &cargo[j];
 				if (theCargo->active)
 				{
-					if (Collision::collision(bullet, theCargo))
+					if (collision(bullet, theCargo))
 					{
-						bullet->active = 0;
+						bullet->active = false;
 						addExplosion(bullet->x, bullet->y, E_SMALL_EXPLOSION);
 						playSound(SFX_HIT);
 						if (theCargo->collectType != P_PHOEBE)
 						{
-							theCargo->active = 0;
+							theCargo->active = false;
 							playSound(SFX_EXPLOSION);
 							for (int i = 0 ; i < 10 ; i++)
-								addExplosion(theCargo->x + Math::rrand(-15, 15), theCargo->y + Math::rrand(-15, 15), E_BIG_EXPLOSION);
+								addExplosion(theCargo->x + rrand(-15, 15), theCargo->y + rrand(-15, 15), E_BIG_EXPLOSION);
 							updateMissionRequirements(M_PROTECT_PICKUP, P_CARGO, 1);
 						}
 					}
@@ -772,16 +753,16 @@ void doBullets()
 			{
 				playSound(SFX_EXPLOSION);
 				for (int i = 0 ; i < 10 ; i++)
-					addExplosion(bullet->x + Math::rrand(-35, 35), bullet->y + Math::rrand(-35, 35), E_BIG_EXPLOSION);
+					addExplosion(bullet->x + rrand(-35, 35), bullet->y + rrand(-35, 35), E_BIG_EXPLOSION);
 
 				if (bullet->flags & WF_TIMEDEXPLOSION)
-					if (checkPlayerShockDamage(bullet->x, bullet->y, 75))
+					if (checkPlayerShockDamage(bullet->x, bullet->y))
 						setInfoLine("Warning: Missile Shockwave Damage!!", FONT_RED);
 			}
-			bullet->active = 0;
+			bullet->active = false;
 		}
 
-		if (bullet->active == 1)
+		if (bullet->active)
 		{
 			prevBullet = bullet;
 			engine.bulletTail = bullet;
