@@ -18,23 +18,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-#include "classes.h"
-
-extern void addCollectable(float x, float y, int type, int value, int life);
-extern void setRadioMessage(signed char face, char *in, int priority);
-
-extern globalEngineVariables engine;
-extern Game currentGame;
-extern Graphics graphics;
-extern object enemy[MAX_ALIENS];
-extern object player;
 extern object cargo[MAX_CARGO];
+
+extern void initCargo();
+extern object *addCargo(object *owner, int cargoType);
+extern void doCargo();
