@@ -18,19 +18,5 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-#include "classes.h"
-
-extern void addExplosion(float x, float y, int type);
-extern void playSound(int sid);
-
-extern globalEngineVariables engine;
-extern Graphics graphics;
+extern void addDebris(int x, int y, int amount);
+extern void doDebris();
