@@ -18,20 +18,5 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "structs.h"
-
-extern void getPlayerInput();
-
-extern globalEngineVariables engine;
-extern object player;
-extern Game currentGame;
-extern devVariables dev;
-
-char lastKeyEvents[] = "                         ";
+extern bool checkPauseRequest();
+extern void addKeyEvent(const char *keyName);
