@@ -18,20 +18,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-#include "classes.h"
-
-extern int isOnScreen(int x, int y, int w, int h);
-
-extern globalEngineVariables engine;
-extern devVariables dev;
-extern object enemy[MAX_ALIENS];
-extern Graphics graphics;
+extern void addExplosion(float x, float y, int type);
+extern void addEngine(object *craft);
+extern void doExplosions();
