@@ -18,16 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-
-extern globalEngineVariables engine;
 extern devVariables dev;
+extern globalEngineVariables engine;
+
+extern void defineGlobals();
