@@ -18,10 +18,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "missions.h"
+#include "Starfighter.h"
 
 // God, I hate this file! :((
 
+Planet systemPlanet[10];
+mission currentMission;
+static mission missions[MAX_MISSIONS];
+
 void initPlanetMissions(signed char system)
 {
 	for (int i = 0 ; i < 10 ; i++)
@@ -202,7 +206,7 @@ Timer Variable:
 -1 : Time up
 -2 : No timer
 */
-void clearAllMissions()
+static void clearAllMissions()
 {
 	for (int m = 0 ; m < MAX_MISSIONS ; m++)
 	{
@@ -303,7 +307,7 @@ void checkTimer()
 	}
 }
 
-void evaluteRequirement(int type, int id, int value, int *completed, int *targetValue, int fontColor)
+static void evaluateRequirement(int type, int id, int *completed, int *targetValue, int fontColor)
 {
 	char message[25];
 
@@ -344,7 +348,7 @@ void evaluteRequirement(int type, int id, int value, int *completed, int *target
 				switch(id)
 				{
 					case P_CARGO:
-						sprintf(message, "Cargo pod destroy!");
+						sprintf(message, "Cargo pod destroyed!");
 						if (currentGame.area == 2) // Get lectured by Sid
 							setRadioMessage(FACE_SID, "Chris, we needed that pod!! I warned you that we couldn't afford to lose a single one!!", 1);
 						break;
@@ -417,7 +421,7 @@ void updateMissionRequirements(int type, int id, int value)
 			{
 				matched = 1;
 				currentMission.targetValue1[i] -= value;
-				evaluteRequirement(type, id, value, &currentMission.completed1[i], &currentMission.targetValue1[i], FONT_CYAN);
+				evaluateRequirement(type, id, &currentMission.completed1[i], &currentMission.targetValue1[i], FONT_CYAN);
 			}
 		}
 	}
@@ -433,7 +437,7 @@ void updateMissionRequirements(int type, int id, int value)
 			if ((currentMission.secondaryType[i] == type) && ((currentMission.target2[i] == id) || (currentMission.target2[i] == CD_ANY)))
 			{
 				currentMission.targetValue2[i] -= value;
-				evaluteRequirement(type, id, value, &currentMission.completed2[i], &currentMission.targetValue2[i], FONT_YELLOW);
+				evaluateRequirement(type, id, &currentMission.completed2[i], &currentMission.targetValue2[i], FONT_YELLOW);
 				return;
 			}
 		}
@@ -473,7 +477,7 @@ void updateMissionRequirements(int type, int id, int value)
 This is only used as few times in the game.
 Missions 11 and 23 to be exact!
 */
-char revealHiddenObjectives()
+static char revealHiddenObjectives()
 {
 	char allDone = 1;
 	char string[255];
@@ -497,20 +501,21 @@ char revealHiddenObjectives()
 		{
 			killAllAliens();
 			syncScriptEvents();
-			enemy[WC_KLINE].active = 1;
+			enemy[WC_KLINE].active = true;
 			enemy[WC_KLINE].x = player.x + 1000;
 			enemy[WC_KLINE].y = player.y;
-			enemy[WC_KLINE].flags += FL_IMMORTAL + FL_NOFIRE;
+			enemy[WC_KLINE].flags |= FL_IMMORTAL | FL_NOFIRE;
 			setTarget(WC_KLINE);
 			loadMusic("music/TranceGeneration.mod");
-			Mix_PlayMusic(engine.music, -1);
+			if ((engine.useAudio) && (engine.useMusic))
+				Mix_PlayMusic(engine.music, -1);
 		}
 	}
 
 	return allDone;
 }
 
-signed char allMissionsCompleted()
+bool allMissionsCompleted()
 {
 	for (int i = 0 ; i < 3 ; i++)
 	{
@@ -605,9 +610,9 @@ signed char allMissionsCompleted()
 		}
 	}
 
-	signed char remaining = 0;
-	signed char add = 0;
-	signed char allDone = 1;
+	signed char remaining;
+	bool add = false;
+	bool allDone = true;
 
 	// Zero objective list for a recount
 	currentMission.remainingObjectives1 = currentMission.remainingObjectives2 = 0;
@@ -620,12 +625,12 @@ signed char allMissionsCompleted()
 			{
 				currentMission.remainingObjectives1++;
 				if (currentMission.primaryType[i] == M_DESTROY_ALL_TARGETS)
-					add = 1;
-				allDone = 0;
+					add = true;
+				allDone = false;
 			}
 
 			if (currentMission.completed1[i] < 0)
-				return 0;
+				return false;
 		}
 		if (currentMission.secondaryType[i] != NONE)
 		{
@@ -633,8 +638,8 @@ signed char allMissionsCompleted()
 			{
 				currentMission.remainingObjectives2++;
 				if (currentMission.secondaryType[i] == M_DESTROY_ALL_TARGETS)
-					add = 1;
-				allDone = 0;
+					add = true;
+				allDone = false;
 			}
 		}
 	}
@@ -646,68 +651,68 @@ signed char allMissionsCompleted()
 
 	// We've only got one objective left and it's destroy all targets,
 	// so stop adding aliens (otherwise it might be impossible to finish!)
-	if ((add == 1) && (remaining == 1))
+	if ((add) && (remaining == 1))
 		engine.addAliens = -1;
 
 	return allDone;
 }
 
-signed char missionFailed()
+bool missionFailed()
 {
 	for (int i = 0 ; i < 3 ; i++)
 	{
 		if (currentMission.completed1[i] < 0)
 		{
-			return 1;
+			return true;
 		}
 	}
 
-	return 0;
+	return false;
 }
 
-void drawBriefScreen()
+static void drawBriefScreen()
 {
 	SDL_Rect r = {0, 0, 800, 2};
 
 	for (int i = 0 ; i < 120 ; i++)
 	{
 		r.y = (i * 2) + 60;
-		SDL_FillRect(graphics.screen, &r, SDL_MapRGB(graphics.screen->format, 0, i, 0));
+		SDL_FillRect(screen, &r, SDL_MapRGB(screen->format, 0, i, 0));
 		r.y = (300 + (i * 2));
-		SDL_FillRect(graphics.screen, &r, SDL_MapRGB(graphics.screen->format, 0, (120 - i), 0));
+		SDL_FillRect(screen, &r, SDL_MapRGB(screen->format, 0, (120 - i), 0));
 	}
 
-	graphics.blevelRect(140, 70, 500, 20, 0x00, 0x77, 0x00);
-	graphics.blevelRect(140, 90, 500, 130, 0x00, 0x33, 0x00);
-	graphics.drawString("Primary Objectives", 150, 74, FONT_WHITE);
+	blevelRect(140, 70, 500, 20, 0x00, 0x77, 0x00);
+	blevelRect(140, 90, 500, 130, 0x00, 0x33, 0x00);
+	drawString("Primary Objectives", 150, 74, FONT_WHITE);
 
 	for (int i = 0 ; i < 3 ; i++)
 	{
 		if ((currentMission.primaryType[i] != NONE) && (currentMission.completed1[i] != OB_HIDDEN))
 		{
-			graphics.drawString(currentMission.primaryObjective[i], 160, 114 + (i * 30), FONT_WHITE);
+			drawString(currentMission.primaryObjective[i], 160, 114 + (i * 30), FONT_WHITE);
 		}
 	}
 
 	if (currentMission.secondaryType[0] != NONE)
 	{
-		graphics.blevelRect(140, 230, 500, 20, 0x00, 0x77, 0x77);
-		graphics.blevelRect(140, 250, 500, 130, 0x00, 0x33, 0x33);
-		graphics.drawString("Secondary Objectives", 150, 234, FONT_WHITE);
+		blevelRect(140, 230, 500, 20, 0x00, 0x77, 0x77);
+		blevelRect(140, 250, 500, 130, 0x00, 0x33, 0x33);
+		drawString("Secondary Objectives", 150, 234, FONT_WHITE);
 
 		for (int i = 0 ; i < 3 ; i++)
 		{
 			if (currentMission.secondaryType[i] != NONE)
 			{
-				graphics.drawString(currentMission.secondaryObjective[i], 160, 274 + (i * 30), FONT_WHITE);
+				drawString(currentMission.secondaryObjective[i], 160, 274 + (i * 30), FONT_WHITE);
 				currentGame.secondaryMissions++;
 			}
 		}
 	}
 
-	graphics.blevelRect(140, 390, 500, 20, 0x77, 0x77, 0x00);
-	graphics.blevelRect(140, 410, 500, 130, 0x33, 0x33, 0x00);
-	graphics.drawString("Additional Information", 150, 394, FONT_WHITE);
+	blevelRect(140, 390, 500, 20, 0x77, 0x77, 0x00);
+	blevelRect(140, 410, 500, 130, 0x33, 0x33, 0x00);
+	drawString("Additional Information", 150, 394, FONT_WHITE);
 }
 
 /*
@@ -717,14 +722,12 @@ mission begins playing here.
 */
 void missionBriefScreen()
 {
-	graphics.clearScreen(graphics.black);
-	graphics.updateScreen();
-
-	SDL_Delay(1000);
+	clearScreen(black);
+	updateScreen();
 
 	if (currentGame.area != MAX_MISSIONS - 1)
 	{
-		graphics.clearScreen(graphics.black);
+		clearScreen(black);
 		drawBriefScreen();
 
 		if (currentMission.timeLimit1[0] > 0)
@@ -735,7 +738,7 @@ void missionBriefScreen()
 				sprintf(temp, "TIME LIMIT: %d minutes", currentMission.timeLimit1[0]);
 			else
 				sprintf(temp, "SURVIVAL FOR %d minutes", currentMission.timeLimit1[0]);
-			graphics.drawString(temp, -1, 500, FONT_RED);
+			drawString(temp, -1, 500, FONT_RED);
 		}
 
 		switch (currentGame.area)
@@ -747,43 +750,43 @@ void missionBriefScreen()
 			case 18:
 			case 24:
 			case 26:
-				graphics.drawString("Phoebe Lexx will not be present", 160, 420, FONT_WHITE);
+				drawString("Phoebe Lexx will not be present", 160, 420, FONT_WHITE);
 				if (currentGame.hasWingMate2)
-					graphics.drawString("Ursula Lexx will not be present", 160, 450, FONT_WHITE);
+					drawString("Ursula Lexx will not be present", 160, 450, FONT_WHITE);
 				break;
 		}
 
 		if ((currentGame.area == 9) || (currentGame.area == 17) || (currentGame.area == 25))
-			graphics.drawString("Sid Wilson will join you on this mission", 160, 480, FONT_WHITE);
+			drawString("Sid Wilson will join you on this mission", 160, 480, FONT_WHITE);
 
-		graphics.updateScreen();
+		updateScreen();
 	}
 
 	loadGameGraphics();
-	graphics.textSurface(4, "Shield", 25, 550, FONT_WHITE);
-	graphics.textSurface(5, "Plasma:", 250, 550, FONT_WHITE);
+	textSurface(4, "Shield", 25, 550, FONT_WHITE);
+	textSurface(5, "Plasma:", 250, 550, FONT_WHITE);
 
 	if (player.weaponType[1] == W_CHARGER)
-		graphics.textSurface(6, "Charge", 385, 550, FONT_WHITE);
+		textSurface(6, "Charge", 385, 550, FONT_WHITE);
 	else if (player.weaponType[1] == W_LASER)
-		graphics.textSurface(6, "Heat", 405, 550, FONT_WHITE);
+		textSurface(6, "Heat", 405, 550, FONT_WHITE);
 	else
-		graphics.textSurface(6, "Rockets:", 385, 550, FONT_WHITE);
+		textSurface(6, "Rockets:", 385, 550, FONT_WHITE);
 
-	graphics.textSurface(7, "Target", 550, 550, FONT_WHITE);
-	graphics.textSurface(8, "Cash: $", 25, 20, FONT_WHITE);
-	graphics.textSurface(9, "Objectives Remaining:", 550, 20, FONT_WHITE);
-	graphics.textSurface(10, "Time Remaining - ", 260, 20, FONT_WHITE);
-	graphics.textSurface(11, "Power", 25, 570, FONT_WHITE);
-	graphics.textSurface(12, "Output", 250, 570, FONT_WHITE);
-	graphics.textSurface(13, "Cooler", 485, 570, FONT_WHITE);
+	textSurface(7, "Target", 550, 550, FONT_WHITE);
+	textSurface(8, "Cash: $", 25, 20, FONT_WHITE);
+	textSurface(9, "Objectives Remaining:", 550, 20, FONT_WHITE);
+	textSurface(10, "Time Remaining - ", 260, 20, FONT_WHITE);
+	textSurface(11, "Power", 25, 570, FONT_WHITE);
+	textSurface(12, "Output", 250, 570, FONT_WHITE);
+	textSurface(13, "Cooler", 485, 570, FONT_WHITE);
 	playRandomTrack();
 
 	if (currentGame.area != MAX_MISSIONS - 1)
 	{
-		graphics.drawString("PRESS CTRL TO CONTINUE...", -1, 550, FONT_WHITE);
+		drawString("PRESS CTRL TO CONTINUE...", -1, 550, FONT_WHITE);
 
-		graphics.updateScreen();
+		updateScreen();
 
 		flushInput();
 		engine.done = 0;
@@ -791,17 +794,15 @@ void missionBriefScreen()
 
 		while (true)
 		{
-			graphics.updateScreen();
+			delayFrame();
 			getPlayerInput();
 			if ((engine.keyState[SDLK_LCTRL]) || (engine.keyState[SDLK_RCTRL]))
 				break;
 		}
 
-		graphics.clearScreen(graphics.black);
-		graphics.updateScreen();
-		graphics.clearScreen(graphics.black);
-
-		SDL_Delay(1000);
+		clearScreen(black);
+		updateScreen();
+		clearScreen(black);
 	}
 
 	engine.gameSection = SECTION_GAME;
@@ -817,15 +818,13 @@ void missionFinishedScreen()
 {
 	if (currentGame.area != MAX_MISSIONS - 1)
 	{
-		graphics.clearScreen(graphics.black);
-		graphics.updateScreen();
-
-		SDL_Delay(1000);
+		clearScreen(black);
+		updateScreen();
 
 		if (currentGame.shots > 0)
 			currentGame.accuracy = (currentGame.hits * 100) / currentGame.shots;
 
-		graphics.clearScreen(graphics.black);
+		clearScreen(black);
 		drawBriefScreen();
 
 		char temp[100];
@@ -835,9 +834,9 @@ void missionFinishedScreen()
 			if (currentMission.primaryType[i] != NONE)
 			{
 				if ((currentGame.area != 17) || ((currentGame.area == 17) && (i != 1)))
-					graphics.drawString("COMPLETED", 550, 114 + (i * 30), FONT_GREEN);
+					drawString("COMPLETED", 550, 114 + (i * 30), FONT_GREEN);
 				else
-					graphics.drawString("FAILED", 550, 114 + (i * 30), FONT_RED);
+					drawString("FAILED", 550, 114 + (i * 30), FONT_RED);
 			}
 		}
 
@@ -850,12 +849,12 @@ void missionFinishedScreen()
 					sprintf(temp, currentMission.secondaryObjective[i]);
 					if (currentMission.completed2[i] >= 1)
 					{
-						graphics.drawString("COMPLETED", 550, 274 + (i * 30), FONT_GREEN);
+						drawString("COMPLETED", 550, 274 + (i * 30), FONT_GREEN);
 						currentGame.secondaryMissionsCompleted++;
 					}
 					else
 					{
-						graphics.drawString("FAILED", 550, 274 + (i * 30), FONT_RED);
+						drawString("FAILED", 550, 274 + (i * 30), FONT_RED);
 					}
 				}
 			}
@@ -864,32 +863,16 @@ void missionFinishedScreen()
 		if (currentMission.remainingObjectives1 + currentMission.remainingObjectives2 == 0)
 		{
 			sprintf(temp, "Shield Bonus: $%.3d", (player.shield * 10));
-			graphics.drawString(temp, -1, 430, FONT_WHITE);
+			drawString(temp, -1, 430, FONT_WHITE);
 			currentGame.cash += (player.shield * 10);
 			currentGame.cashEarned += (player.shield * 10);
 		}
 
 		currentGame.timeTaken += engine.timeTaken;
 
-		signed char clock = 0;
-		while (engine.timeTaken > 3599)
-		{
-			clock++;
-			engine.timeTaken -= 3600;
-		}
+		snprintf(temp, sizeof temp, "Mission Time: %2d:%02d:%02d", engine.timeTaken / 3600, (engine.timeTaken / 60) % 60, engine.timeTaken % 60);
 
-		sprintf(temp, "Mission Time: %.2d", clock);
-
-		clock = 0;
-		while (engine.timeTaken > 59)
-		{
-			clock++;
-			engine.timeTaken -= 60;
-		}
-
-		sprintf(temp, "%s:%.2d:%.2d", temp, clock, engine.timeTaken);
-
-		graphics.drawString(temp, -1, 500, FONT_WHITE);
+		drawString(temp, -1, 500, FONT_WHITE);
 
 		// Do some mission specific stuff here...
 		if (currentGame.area == 1)
@@ -901,7 +884,7 @@ void missionFinishedScreen()
 
 		checkForBossMission();
 
-		graphics.updateScreen();
+		updateScreen();
 
 		flushInput();
 		engine.done = 0;
@@ -909,7 +892,7 @@ void missionFinishedScreen()
 
 		while (true)
 		{
-			graphics.updateScreen();
+			delayFrame();
 			getPlayerInput();
 			if ((engine.keyState[SDLK_LCTRL]) || (engine.keyState[SDLK_RCTRL]))
 				break;
@@ -925,7 +908,7 @@ void missionFinishedScreen()
 
 #if USEPACK
 
-void loadMissions()
+static void loadMissions()
 {
 	clearAllMissions();
 
@@ -996,7 +979,7 @@ void initMissions(){loadMissions();}
 
 #else
 
-void saveMissions()
+static void saveMissions()
 {
 	FILE *fp;
 	char filename[65];
