@@ -18,28 +18,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-#include "classes.h"
-
-extern void unpack(char *file, signed char fileType);
-extern SDL_Surface *loadImage(char *filename);
-extern Mix_Chunk *loadSound(char *filename);
-extern int locateDataInPak(char *file, signed char required);
-extern void setAlienShapes();
-extern void setWeaponShapes();
+extern void loadBackground(const char *filename);
 extern void loadGameGraphics();
-
-extern globalEngineVariables engine;
-extern object weapon[MAX_WEAPONS];
-extern Mix_Chunk *sound[MAX_SOUNDS];
-extern object enemy[MAX_ALIENS];
-extern Graphics graphics;
-extern Game currentGame;
+extern void loadSound();
+extern void freeSound();
+extern void loadFont();
