@@ -18,14 +18,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "shop.h"
+#include "Starfighter.h"
 
-void drawSecondaryWeaponSurface()
+static ShopItem shopItems[MAX_SHOPITEMS];
+static signed char shopSelectedItem;
+
+static void drawSecondaryWeaponSurface()
 {
 	char description[50];
 	strcpy(description, "");
 
-	graphics.drawString("Secondary Weapon", 10, 3, FONT_WHITE, graphics.shopSurface[2]);
+	drawString("Secondary Weapon", 10, 3, FONT_WHITE, shopSurface[2]);
 
 	switch (player.weaponType[1])
 	{
@@ -57,70 +60,70 @@ void drawSecondaryWeaponSurface()
 			strcpy(description, "Type : Mcr Homing Missiles");
 			break;
 	}
-	graphics.drawString(description, 10, 22, FONT_WHITE, graphics.shopSurface[2]);
+	drawString(description, 10, 22, FONT_WHITE, shopSurface[2]);
 
 	if ((player.weaponType[1] != W_LASER) && (player.weaponType[1] != W_CHARGER) && (player.weaponType[1] != W_NONE))
 	{
 		sprintf(description, "Capacity : %d", currentGame.maxRocketAmmo);
-		graphics.drawString(description, 10, 37, FONT_WHITE, graphics.shopSurface[2]);
+		drawString(description, 10, 37, FONT_WHITE, shopSurface[2]);
 	}
 }
 
-void adjustShopPrices()
+static void adjustShopPrices()
 {
 	shopItems[0].price = (500 * currentGame.maxPlasmaOutput);
 	shopItems[1].price = (500 * currentGame.maxPlasmaDamage);
-	shopItems[2].price = (500 * (16 - currentGame.maxPlasmaRate));
+	shopItems[2].price = (500 * (currentGame.maxPlasmaRate * 2 - 1));
 
-	shopItems[5].price = (2000 * weapon[0].ammo[0]);
-	shopItems[6].price = (2000 * weapon[0].damage);
-	shopItems[7].price = (2000 * (16 - weapon[0].reload[0]));
+	shopItems[5].price = (2000 * currentGame.minPlasmaOutput);
+	shopItems[6].price = (2000 * currentGame.minPlasmaDamage);
+	shopItems[7].price = (2000 * (currentGame.minPlasmaRate * 2 - 1));
 
 	shopItems[8].price = (5 * currentGame.maxPlasmaAmmo);
 	shopItems[9].price = (25 * currentGame.maxRocketAmmo);
 	
-	if (currentGame.maxPlasmaOutput == 5)
+	if (currentGame.maxPlasmaOutput >= 5)
 		shopItems[0].price = 0;
 
-	if (currentGame.maxPlasmaDamage == 5)
+	if (currentGame.maxPlasmaDamage >= 5)
 		shopItems[1].price = 0;
 
-	if (currentGame.maxPlasmaRate == 7)
+	if (currentGame.maxPlasmaRate >= 5)
 		shopItems[2].price = 0;
 		
-	if (weapon[0].ammo[0] == 3)
+	if (currentGame.minPlasmaOutput >= 3)
 		shopItems[5].price = 0;
 
-	if (weapon[0].damage == 3)
+	if (currentGame.minPlasmaDamage >= 3)
 		shopItems[6].price = 0;
 
-	if (weapon[0].reload[0] == 11)
+	if (currentGame.minPlasmaRate >= 3)
 		shopItems[7].price = 0;
 }
 
-void drawShop()
+static void drawShop()
 {
 	adjustShopPrices();
 
 	for (int i = 0 ; i < MAX_SHOPSHAPES ; i++)
 	{
-		if (graphics.shopSurface[i] != NULL)
+		if (shopSurface[i] != NULL)
 		{
-			SDL_FreeSurface(graphics.shopSurface[i]);
+			SDL_FreeSurface(shopSurface[i]);
 		}
 	}
 
 	for (int i = 0 ; i < 3 ; i++)
-		graphics.shopSurface[i] = graphics.createSurface(246, 91);
+		shopSurface[i] = createSurface(246, 91);
 
 	for (int i = 0 ; i < 3 ; i++)
 	{
-		graphics.blevelRect(graphics.shopSurface[i], 0, 0, 245, 90, 0x00, 0x00, 0x55);
-		graphics.blevelRect(graphics.shopSurface[i], 0, 0, 245, 20, 0x00, 0x00, 0x99);
+		blevelRect(shopSurface[i], 0, 0, 245, 90, 0x00, 0x00, 0x55);
+		blevelRect(shopSurface[i], 0, 0, 245, 20, 0x00, 0x00, 0x99);
 	}
 
-	graphics.shopSurface[4] = graphics.alphaRect(601, 101, 0x00, 0x00, 0x00);
-	graphics.blevelRect(graphics.shopSurface[4], 0, 0, 600, 100, 0x00, 0x00, 0x33);
+	shopSurface[4] = alphaRect(601, 101, 0x00, 0x00, 0x00);
+	blevelRect(shopSurface[4], 0, 0, 600, 100, 0x00, 0x00, 0x33);
 
 	switch (shopSelectedItem)
 	{
@@ -135,58 +138,58 @@ void drawShop()
 		case 1:
 		case 2:
 		case 8:
-			graphics.blevelRect(graphics.shopSurface[1], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			graphics.blevelRect(graphics.shopSurface[1], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			blevelRect(shopSurface[1], 0, 0, 245, 90, 0x55, 0x00, 0x00);
+			blevelRect(shopSurface[1], 0, 0, 245, 20, 0x99, 0x00, 0x00);
 			break;
 		case 3:
 		case 4:
-			graphics.blevelRect(graphics.shopSurface[4], 0, 0, 600, 100, 0x33, 0x00, 0x00);
+			blevelRect(shopSurface[4], 0, 0, 600, 100, 0x33, 0x00, 0x00);
 			break;
 		case 5:
 		case 6:
 		case 7:
-			graphics.blevelRect(graphics.shopSurface[0], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			graphics.blevelRect(graphics.shopSurface[0], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			blevelRect(shopSurface[0], 0, 0, 245, 90, 0x55, 0x00, 0x00);
+			blevelRect(shopSurface[0], 0, 0, 245, 20, 0x99, 0x00, 0x00);
 			break;
 		default:
-			graphics.blevelRect(graphics.shopSurface[2], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			graphics.blevelRect(graphics.shopSurface[2], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			blevelRect(shopSurface[2], 0, 0, 245, 90, 0x55, 0x00, 0x00);
+			blevelRect(shopSurface[2], 0, 0, 245, 20, 0x99, 0x00, 0x00);
 			break;
 	}
 
 	char description[100];
 	strcpy(description, "");
 
-	graphics.drawString("Primary Weapon", 10, 3, FONT_WHITE, graphics.shopSurface[0]);
-	sprintf(description, "Plasma Cannons : %d", weapon[0].ammo[0]);
-	graphics.drawString(description, 10, 22, FONT_WHITE, graphics.shopSurface[0]);
-	sprintf(description, "Plasma Power   : Stage %d", weapon[0].damage);
-	graphics.drawString(description, 10, 37, FONT_WHITE, graphics.shopSurface[0]);
-	sprintf(description, "Cooler         : Stage %d", ((15 - weapon[0].reload[0]) / 2) + 1);
-	graphics.drawString(description, 10, 52, FONT_WHITE, graphics.shopSurface[0]);
+	drawString("Primary Weapon", 10, 3, FONT_WHITE, shopSurface[0]);
+	sprintf(description, "Plasma Cannons : %d", currentGame.minPlasmaOutput);
+	drawString(description, 10, 22, FONT_WHITE, shopSurface[0]);
+	sprintf(description, "Plasma Power   : Stage %d", currentGame.minPlasmaDamage);
+	drawString(description, 10, 37, FONT_WHITE, shopSurface[0]);
+	sprintf(description, "Cooler         : Stage %d", currentGame.minPlasmaRate);
+	drawString(description, 10, 52, FONT_WHITE, shopSurface[0]);
 
-	graphics.drawString("Powerup Weapon", 10, 3, FONT_WHITE, graphics.shopSurface[1]);
+	drawString("Powerup Weapon", 10, 3, FONT_WHITE, shopSurface[1]);
 	sprintf(description, "Plasma Output    : Stage %d", currentGame.maxPlasmaOutput);
-	graphics.drawString(description, 10, 22, FONT_WHITE, graphics.shopSurface[1]);
+	drawString(description, 10, 22, FONT_WHITE, shopSurface[1]);
 	sprintf(description, "Plasma Condensor : Stage %d", currentGame.maxPlasmaDamage);
-	graphics.drawString(description, 10, 37, FONT_WHITE, graphics.shopSurface[1]);
-	sprintf(description, "Liquid Nitrogen  : Stage %d", ((15 - currentGame.maxPlasmaRate) / 2) + 1);
-	graphics.drawString(description, 10, 52, FONT_WHITE, graphics.shopSurface[1]);
+	drawString(description, 10, 37, FONT_WHITE, shopSurface[1]);
+	sprintf(description, "Liquid Nitrogen  : Stage %d", currentGame.maxPlasmaRate);
+	drawString(description, 10, 52, FONT_WHITE, shopSurface[1]);
 	sprintf(description, "Plasma Capacity  : %d", currentGame.maxPlasmaAmmo);
-	graphics.drawString(description, 10, 67, FONT_WHITE, graphics.shopSurface[1]);
+	drawString(description, 10, 67, FONT_WHITE, shopSurface[1]);
 
 	drawSecondaryWeaponSurface();
 
-	graphics.shopSurface[3] = graphics.createSurface(601, 121);
+	shopSurface[3] = createSurface(601, 121);
 
-	graphics.blevelRect(graphics.shopSurface[3], 0, 0, 600, 120, 0x00, 0x00, 0x22);
+	blevelRect(shopSurface[3], 0, 0, 600, 120, 0x00, 0x00, 0x22);
 
-	graphics.drawString("Temporary Weapons", 10, 2, FONT_WHITE, graphics.shopSurface[3]);
-	graphics.drawString("Ammo and Storage", 260, 2, FONT_WHITE, graphics.shopSurface[3]);
+	drawString("Temporary Weapons", 10, 2, FONT_WHITE, shopSurface[3]);
+	drawString("Ammo and Storage", 260, 2, FONT_WHITE, shopSurface[3]);
 
-	graphics.drawString("Primary Weapons", 10, 62, FONT_WHITE, graphics.shopSurface[3]);
+	drawString("Primary Weapons", 10, 62, FONT_WHITE, shopSurface[3]);
 
-	graphics.drawString("Secondary Weapons", 260, 62, FONT_WHITE, graphics.shopSurface[3]);
+	drawString("Secondary Weapons", 260, 62, FONT_WHITE, shopSurface[3]);
 
 	signed char icons = MAX_SHOPITEMS;
 
@@ -198,50 +201,50 @@ void drawShop()
 		icons = 15;
 
 	for (int i = 0 ; i < icons ; i++)
-		graphics.blit(graphics.shape[shopItems[i].image], shopItems[i].x - 90, shopItems[i].y - 178, graphics.shopSurface[3]);
+		blit(shape[shopItems[i].image], shopItems[i].x - 90, shopItems[i].y - 178, shopSurface[3]);
 
 	sprintf(description, "Shield Units : %d", currentGame.shieldUnits * 25);
-	graphics.drawString(description, 10, 4, FONT_WHITE, graphics.shopSurface[4]);
+	drawString(description, 10, 4, FONT_WHITE, shopSurface[4]);
 	sprintf(description, "Cash : $%d", currentGame.cash);
-	graphics.drawString(description, 10, 80, FONT_WHITE, graphics.shopSurface[4]);
+	drawString(description, 10, 80, FONT_WHITE, shopSurface[4]);
 	sprintf(description, "Plasma Cells : %.3d", player.ammo[0]);
-	graphics.drawString(description, 430, 4, FONT_WHITE, graphics.shopSurface[4]);
+	drawString(description, 430, 4, FONT_WHITE, shopSurface[4]);
 	sprintf(description, "Rockets : %.3d", player.ammo[1]);
-	graphics.drawString(description, 475, 80, FONT_WHITE, graphics.shopSurface[4]);
+	drawString(description, 475, 80, FONT_WHITE, shopSurface[4]);
 
-	graphics.shopSurface[5] = graphics.createSurface(601, 56);
-	graphics.blevelRect(graphics.shopSurface[5], 0, 0, 600, 35, 0x00, 0x99, 0x00);
-	graphics.blevelRect(graphics.shopSurface[5], 0, 20, 600, 35, 0x00, 0x33, 0x00);
-	graphics.drawString("Information", 5, 4, FONT_WHITE, graphics.shopSurface[5]);
+	shopSurface[5] = createSurface(601, 56);
+	blevelRect(shopSurface[5], 0, 0, 600, 35, 0x00, 0x99, 0x00);
+	blevelRect(shopSurface[5], 0, 20, 600, 35, 0x00, 0x33, 0x00);
+	drawString("Information", 5, 4, FONT_WHITE, shopSurface[5]);
 
 	switch (shopSelectedItem)
 	{
 		case -1:
 			break;
 		case -2:
-			graphics.drawString("You don't have enough money", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("You don't have enough money", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -3:
-			graphics.drawString("Cannot upgrade ship", 5, 22, FONT_WHITE, graphics.shopSurface[5]);
-			graphics.drawString("Hardware capacity has been reached", 20, 38, FONT_CYAN, graphics.shopSurface[5]);
+			drawString("Cannot upgrade ship", 5, 22, FONT_WHITE, shopSurface[5]);
+			drawString("Hardware capacity has been reached", 20, 38, FONT_CYAN, shopSurface[5]);
 			break;
 		case -4:
-			graphics.drawString("Ammunition limit reached", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("Ammunition limit reached", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -5:
-			graphics.drawString("You cannot sell that item", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("You cannot sell that item", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -6:
-			graphics.drawString("Nothing to sell", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("Nothing to sell", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -7:
-			graphics.drawString("Rockets cannot be bought for Laser or Charger Cannon", 5, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("Rockets cannot be bought for Laser or Charger Cannon", 5, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -8:
-			graphics.drawString("You already have that weapon", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("You already have that weapon", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		case -9:
-			graphics.drawString("This weapon's ammo limit has been reached", 20, 30, FONT_WHITE, graphics.shopSurface[5]);
+			drawString("This weapon's ammo limit has been reached", 20, 30, FONT_WHITE, shopSurface[5]);
 			break;
 		default:
 			if (shopItems[shopSelectedItem].price != 0)
@@ -252,15 +255,15 @@ void drawShop()
 			{
 				sprintf(description, "%s (N/A)", shopItems[shopSelectedItem].description);
 			}
-			graphics.drawString(shopItems[shopSelectedItem].name, 5, 22, FONT_WHITE, graphics.shopSurface[5]);
-			graphics.drawString(description, 20, 38, FONT_CYAN, graphics.shopSurface[5]);
+			drawString(shopItems[shopSelectedItem].name, 5, 22, FONT_WHITE, shopSurface[5]);
+			drawString(description, 20, 38, FONT_CYAN, shopSurface[5]);
 			break;
 	}
 }
 
 #if USEPACK
 
-void loadShop()
+static void loadShop()
 {
 	char name[255], description[255];
 	int price, image, x, y;
@@ -296,7 +299,7 @@ void loadShop()
 
 	shopSelectedItem = -1;
 
-	player.image[0] = graphics.shape[0];
+	player.image[0] = shape[0];
 	player.x = 380;
 	player.y = 95;
 
@@ -307,7 +310,7 @@ void initShop(){loadShop();}
 
 #else
 
-void saveShop()
+static void saveShop()
 {
 	FILE *fp;
 
@@ -414,7 +417,7 @@ void initShop()
 
 	shopItems[13].price = 7500;
 	strcpy(shopItems[13].name, "Homing Missile Launcher");
-	strcpy(shopItems[13].description, "Fires homing missile");
+	strcpy(shopItems[13].description, "Fires homing missile (max 20 missiles)");
 	shopItems[13].image = 22;
 
 	shopItems[14].price = 10000;
@@ -424,12 +427,12 @@ void initShop()
 
 	shopItems[15].price = 20000;
 	strcpy(shopItems[15].name, "Dual Homing Missile Launcher");
-	strcpy(shopItems[15].description, "Fires two homing missiles");
+	strcpy(shopItems[15].description, "Fires two homing missiles (max 10 missiles)");
 	shopItems[15].image = 24;
 
 	shopItems[16].price = 25000;
 	strcpy(shopItems[16].name, "Homing Micro Missile Launcher");
-	strcpy(shopItems[16].description, "Fires several small homing missiles");
+	strcpy(shopItems[16].description, "Fires several small homing missiles (max 10)");
 	shopItems[16].image = 25;
 
 	for (int i = 0 ; i < 3 ; i++)
@@ -456,7 +459,7 @@ void initShop()
 		shopItems[i + 8].y = 200;
 	}
 
-	for (int i = 0 ; i < 8 ; i++)
+	for (int i = 0 ; i < 7 ; i++)
 	{
 		shopItems[i + 10].x = 350 + (i * 50);
 		shopItems[i + 10].y = 260;
@@ -464,7 +467,7 @@ void initShop()
 
  	shopSelectedItem = -1;
 
-	player.image[0] = graphics.shape[0];
+	player.image[0] = shape[0];
 	player.x = 380;
 	player.y = 95;
 
@@ -475,7 +478,7 @@ void initShop()
 
 #endif
 
-void buy(int i)
+static void buy(int i)
 {
 	if ((currentGame.cash < shopItems[i].price) && (!engine.cheatCash))
 	{
@@ -487,24 +490,24 @@ void buy(int i)
 	switch(i)
 	{
 		case 0:
-			if (currentGame.maxPlasmaOutput == 5)
+			if (currentGame.maxPlasmaOutput >= 5)
 				{shopSelectedItem = -3; return;}
 			currentGame.maxPlasmaOutput++;
 			break;
 		case 1:
-			if (currentGame.maxPlasmaDamage == 5)
+			if (currentGame.maxPlasmaDamage >= 5)
 				{shopSelectedItem = -3; return;}
 			currentGame.maxPlasmaDamage++;
 			break;
 		case 2:
-			if (currentGame.maxPlasmaRate == 7)
+			if (currentGame.maxPlasmaRate >= 5)
 				{shopSelectedItem = -3; return;}
-			currentGame.maxPlasmaRate -= 2;
+			currentGame.maxPlasmaRate++;
 			break;
 		case 3:
-			if (player.ammo[0] == currentGame.maxPlasmaAmmo)
+			if (player.ammo[0] >= currentGame.maxPlasmaAmmo)
 				{shopSelectedItem = -4; return;}
-			Math::limitChar(&(player.ammo[0] += 10), 0, currentGame.maxPlasmaAmmo);
+			limitCharAdd(&player.ammo[0], 10, 0, currentGame.maxPlasmaAmmo);
 			break;
 		case 4:
 			if ((player.weaponType[1] == W_CHARGER) || (player.weaponType[1] == W_LASER))
@@ -520,35 +523,41 @@ void buy(int i)
 			player.ammo[1]++;
 			break;
 		case 5:
-			if (weapon[0].ammo[0] == 3)
+			if (currentGame.minPlasmaOutput >= 3)
 				{shopSelectedItem = -3; return;}
-			weapon[0].ammo[0]++;
-			if (currentGame.maxPlasmaOutput < weapon[0].ammo[0])
-				currentGame.maxPlasmaOutput = weapon[0].ammo[0];
+			currentGame.minPlasmaOutput++;
+			if (currentGame.maxPlasmaOutput < currentGame.minPlasmaOutput)
+				currentGame.maxPlasmaOutput = currentGame.minPlasmaOutput;
 			break;
 		case 6:
-			if (weapon[0].damage == 3)
+			if (currentGame.minPlasmaDamage >= 3)
 				{shopSelectedItem = -3; return;}
-			weapon[0].damage++;
-			if (currentGame.maxPlasmaDamage < weapon[0].damage)
-				currentGame.maxPlasmaDamage = weapon[0].damage;
+			currentGame.minPlasmaDamage++;
+			if (currentGame.maxPlasmaDamage < currentGame.minPlasmaDamage)
+				currentGame.maxPlasmaDamage = currentGame.minPlasmaDamage;
 			break;
 		case 7:
-			if (weapon[0].reload[0] == 11)
+			if (currentGame.minPlasmaRate >= 3)
 				{shopSelectedItem = -3; return;}
-			weapon[0].reload[0] -= 2;
-			if (currentGame.maxPlasmaRate > weapon[0].reload[0])
-				currentGame.maxPlasmaRate = weapon[0].reload[0];
+			currentGame.minPlasmaRate++;
+			if (currentGame.maxPlasmaRate < currentGame.minPlasmaRate)
+				currentGame.maxPlasmaRate = currentGame.minPlasmaRate;
 			break;
 		case 8:
-			if (currentGame.maxPlasmaAmmo == 250)
+			if (currentGame.maxPlasmaAmmo >= 250)
 				{shopSelectedItem = -3; return;}
-			Math::limitChar(&(currentGame.maxPlasmaAmmo += 10), 0, 250);
+			limitCharAdd(&currentGame.maxPlasmaAmmo, 10, 0, 250);
 			break;
 		case 9:
 			if ((player.weaponType[1] == W_CHARGER) || (player.weaponType[1] == W_LASER))
 				{shopSelectedItem = -7; return;}
-			if (currentGame.maxRocketAmmo == 50)
+			if ((player.weaponType[1] == W_HOMING_MISSILE) && (currentGame.maxRocketAmmo >= 20))
+				{shopSelectedItem = -9; return;}
+			if ((player.weaponType[1] == W_DOUBLE_HOMING_MISSILES) && (currentGame.maxRocketAmmo >= 10))
+				{shopSelectedItem = -9; return;}
+			if ((player.weaponType[1] == W_MICRO_HOMING_MISSILES) && (currentGame.maxRocketAmmo >= 10))
+				{shopSelectedItem = -9; return;}
+			if (currentGame.maxRocketAmmo >= 50)
 				{shopSelectedItem = -3; return;}
 			currentGame.maxRocketAmmo += 5;
 			break;
@@ -556,18 +565,21 @@ void buy(int i)
 			if (player.weaponType[1] == W_DOUBLE_ROCKETS)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_DOUBLE_ROCKETS;
+			limitChar(&currentGame.maxRocketAmmo, 10, 50);
 			shopSelectedItem = -1;
 			break;
 		case 11:
 			if (player.weaponType[1] == W_MICRO_ROCKETS)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_MICRO_ROCKETS;
+			limitChar(&currentGame.maxRocketAmmo, 10, 50);
 			shopSelectedItem = -1;
 			break;
 		case 12:
 			if (player.weaponType[1] == W_LASER)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_LASER;
+			currentGame.maxRocketAmmo = 0;
 			player.ammo[1] = 0;
 			shopSelectedItem = -1;
 			break;
@@ -575,13 +587,15 @@ void buy(int i)
 			if (player.weaponType[1] == W_HOMING_MISSILE)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_HOMING_MISSILE;
-			Math::limitChar(&player.ammo[1], 0, 20);
+			limitChar(&currentGame.maxRocketAmmo, 5, 20);
+			limitChar(&player.ammo[1], 0, 20);
 			shopSelectedItem = -1;
 			break;
 		case 14:
 			if (player.weaponType[1] == W_CHARGER)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_CHARGER;
+			currentGame.maxRocketAmmo = 0;
 			player.ammo[1] = 0;
 			shopSelectedItem = -1;
 			break;
@@ -589,14 +603,16 @@ void buy(int i)
 			if (player.weaponType[1] == W_DOUBLE_HOMING_MISSILES)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_DOUBLE_HOMING_MISSILES;
-			Math::limitChar(&player.ammo[1], 0, 10);
+			limitChar(&currentGame.maxRocketAmmo, 5, 10);
+			limitChar(&player.ammo[1], 0, 10);
 			shopSelectedItem = -1;
 			break;
 		case 16:
 			if (player.weaponType[1] == W_MICRO_HOMING_MISSILES)
 				{shopSelectedItem = -8; return;}
 			player.weaponType[1] = W_MICRO_HOMING_MISSILES;
-			Math::limitChar(&player.ammo[1], 0, 10);
+			limitChar(&currentGame.maxRocketAmmo, 5, 10);
+			limitChar(&player.ammo[1], 0, 10);
 			shopSelectedItem = -1;
 			break;
 	}
@@ -605,64 +621,64 @@ void buy(int i)
 		currentGame.cash -= shopItems[i].price;
 }
 
-void sell(int i)
+static void sell(int i)
 {
 	switch (i)
 	{
 		case 0:
-			if (currentGame.maxPlasmaOutput == 2)
+			if (currentGame.maxPlasmaOutput <= 2)
 				{shopSelectedItem = -5; return;}
 			currentGame.maxPlasmaOutput--;
 			break;
 		case 1:
-			if (currentGame.maxPlasmaDamage == 2)
+			if (currentGame.maxPlasmaDamage <= 2)
 				{shopSelectedItem = -5; return;}
 			currentGame.maxPlasmaDamage--;
 			break;
 		case 2:
-			if (currentGame.maxPlasmaRate == 13)
+			if (currentGame.maxPlasmaRate <= 2)
 				{shopSelectedItem = -5; return;}
-			currentGame.maxPlasmaRate += 2;
+			currentGame.maxPlasmaRate--;
 			break;
 		case 3:
-			if (player.ammo[0] == 0)
+			if (player.ammo[0] <= 0)
 				{shopSelectedItem = -6; return;}
 			if (player.ammo[0] > 9)
-				Math::limitChar(&(player.ammo[0] -= 10), 0, currentGame.maxPlasmaAmmo);
+				limitCharAdd(&player.ammo[0], -10, 0, currentGame.maxPlasmaAmmo);
 			else
 				player.ammo[0] = 0;
 			break;
 		case 4:
-			if (player.ammo[1] == 0)
+			if (player.ammo[1] <= 0)
 				{shopSelectedItem = -6; return;}
 			player.ammo[1]--;
 			break;
 		case 5:
-			if (weapon[0].ammo[0] == 1)
+			if (currentGame.minPlasmaOutput <= 1)
 				{shopSelectedItem = -5; return;}
-			weapon[0].ammo[0]--;
+			currentGame.minPlasmaOutput--;
 			break;
 		case 6:
-			if (weapon[0].damage == 1)
+			if (currentGame.minPlasmaDamage <= 1)
 				{shopSelectedItem = -5; return;}
-			weapon[0].damage--;
+			currentGame.minPlasmaDamage--;
 			break;
 		case 7:
-			if (weapon[0].reload[0] == 15)
+			if (currentGame.minPlasmaRate <= 1)
 				{shopSelectedItem = -5; return;}
-			weapon[0].reload[0] += 2;
+			currentGame.minPlasmaRate--;
 			break;
 		case 8:
-			if (currentGame.maxPlasmaAmmo == 100)
+			if (currentGame.maxPlasmaAmmo <= 100)
 				{shopSelectedItem = -1; return;}
 			currentGame.maxPlasmaAmmo -= 10;
-			Math::limitChar(&player.ammo[0], 0, currentGame.maxPlasmaAmmo);
+			limitChar(&player.ammo[0], 0, currentGame.maxPlasmaAmmo);
 			break;
 		case 9:
-			if (currentGame.maxRocketAmmo == 0)
+			if (currentGame.maxRocketAmmo <= 0)
 				{shopSelectedItem = -1; return;}
 			currentGame.maxRocketAmmo -= 5;
-			Math::limitChar(&player.ammo[1], 0, currentGame.maxRocketAmmo);
+			limitChar(&player.ammo[1], 0, currentGame.maxRocketAmmo);
 			break;
 		case 10:
 			if (player.weaponType[1] != W_DOUBLE_ROCKETS)
@@ -710,25 +726,26 @@ void sell(int i)
 			break;
 	}
 
+	adjustShopPrices();
 	currentGame.cash += (shopItems[i].price / 2);
 }
 
 void showShop()
 {
- 	graphics.blit(graphics.shopSurface[0], 20, 395);
-	graphics.blit(graphics.shopSurface[1], 275, 395);
-	graphics.blit(graphics.shopSurface[2], 530, 395);
-	graphics.blit(graphics.shopSurface[3], 100, 180);
-	graphics.blit(graphics.shopSurface[4], 100, 50);
-	graphics.blit(graphics.shopSurface[5], 100, 320);
+ 	blit(shopSurface[0], 20, 395);
+	blit(shopSurface[1], 275, 395);
+	blit(shopSurface[2], 530, 395);
+	blit(shopSurface[3], 100, 180);
+	blit(shopSurface[4], 100, 50);
+	blit(shopSurface[5], 100, 320);
 
 	if (shopSelectedItem > -1)
 	{
-		graphics.blit(graphics.shape[27], 60, 350);
-		graphics.blit(graphics.shape[28], 710, 350);
+		blit(shape[27], 60, 350);
+		blit(shape[28], 710, 350);
 	}
 
-	graphics.blit(graphics.shape[29], (int)player.x, (int)player.y);
+	blit(shape[29], (int)player.x, (int)player.y);
 
 	signed char icons = MAX_SHOPITEMS;
 
@@ -743,7 +760,7 @@ void showShop()
 	{
 		for (int i = 0 ; i < icons ; i++)
 		{
-			if (Collision::collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, shopItems[i].x, shopItems[i].y, 32, 25))
+			if (collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, shopItems[i].x, shopItems[i].y, 32, 25))
 			{
 				shopSelectedItem = i;
 				engine.keyState[SDLK_LCTRL] = engine.keyState[SDLK_RCTRL] = 0;
@@ -753,14 +770,14 @@ void showShop()
 
 		if (shopSelectedItem > -1)
 		{
-			if (Collision::collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 60, 350, 24, 16))
+			if (collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 60, 350, 24, 16))
 			{
 				buy(shopSelectedItem);
 				engine.keyState[SDLK_LCTRL] = engine.keyState[SDLK_RCTRL] = 0;
 				drawShop();
 			}
 
-			if (Collision::collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 700, 350, 24, 16))
+			if (collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 700, 350, 24, 16))
 			{
 				sell(shopSelectedItem);
 				engine.keyState[SDLK_LCTRL] = engine.keyState[SDLK_RCTRL] = 0;
