@@ -18,19 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-
-#include "defs.h"
-#include "structs.h"
-#include "classes.h"
-
-extern int locateDataInPak(char *file, signed char required);
-
-extern Graphics graphics;
 extern object weapon[MAX_WEAPONS];
 
+extern void setWeaponShapes();
+extern void initWeapons();
